%%
%% This is file `htexture.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref.dtx  (with options: `textures')
%% 
%% Copyright
%% 1995-2001 Sebastian Rahtz, with portions written by David Carlisle and Heiko Oberdiek
%% 2001-2015 Heiko Oberdiek
%% 2016-2019 Oberdiek Package Support Group
%% 2019-2026 LaTeX Project
%%      https://github.com/latex3/hyperref/issues
%% 
%% This file is part of the `Hyperref Bundle'.
%% -------------------------------------------
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status `maintained'.
%% 
%% The Current Maintainer of this work is the LaTeX Project.
%% 
%% The list of all files belonging to the `Hyperref Bundle' is
%% given in the file `manifest.txt'.
%% 
%% File: hyperref.dtx
\ProvidesFile{htexture.def}
  [2026-01-29 v7.01p %
  Hyperref driver for Textures]
\Hy@VersionCheck{htexture.def}
\providecommand*{\XR@ext}{pdf}
\begingroup
  \obeylines %
  \gdef\Hy@ps@CR{\noexpand
  }%
\endgroup %
\def\literalps@out#1{%
  \special{postscript 0 0 transform}%
  \special{rawpostscript itransform moveto\Hy@ps@CR #1}%
}%
\def\headerps@out#1{%
  \special{%
    prepostscript TeXdict begin\Hy@ps@CR
      #1\Hy@ps@CR
    end%
  }%
}%
\g@addto@macro\Hy@FirstPageHook{%
  \headerps@out{%
    /betterpdfmark {%
      systemdict begin %
        dup /BP eq%
        {cleartomark gsave nulldevice [}%
        {dup /EP eq%
          {cleartomark cleartomark grestore}%
          {cleartomark}%
          ifelse%
        }ifelse %
      end%
    }def\Hy@ps@CR
    __pdfmark__ not{/pdfmark /betterpdfmark load def}if%
  }% end of \headerps@out
}% end of \AddToHook{shipout/firstpage}
\input{pdfmark.def}%
\ifx\@pdfproducer\relax
  \def\@pdfproducer{Textures + Distiller}%
\fi
\providecommand*\@pdfborder{0 0 1}
\providecommand*\@pdfborderstyle{}
\providecommand*\@pdfview{XYZ}
\providecommand*\@pdfviewparams{ H.V}
\Hy@AtBeginDocument{%
  \headerps@out{%
    /vsize {\Hy@pageheight} def%
    /DvipsToPDF {} def%
    /PDFToDvips {} def%
    /BPToDvips {} def%
    /HyperBorder  { 1 PDFToDvips } def\Hy@ps@CR
    /H.V {pdf@hoff pdf@voff null} def\Hy@ps@CR
    /H.B {/Rect[pdf@llx pdf@lly pdf@urx pdf@ury]} def\Hy@ps@CR
    /H.S {%
      currentpoint %
      HyperBorder add /pdf@lly exch def %
      dup DvipsToPDF 72 add /pdf@hoff exch def %
      HyperBorder sub /pdf@llx exch def%
    } def\Hy@ps@CR
    /H.L {%
      2 sub %
      PDFToDvips /HyperBase exch def %
      currentpoint %
      HyperBase sub /pdf@ury exch def%
      /pdf@urx exch def%
    } def\Hy@ps@CR
    /H.A {%
      H.L %
      currentpoint exch pop %
      vsize 72 sub exch DvipsToPDF %
      HyperBase sub % baseline skip
      sub /pdf@voff exch def%
    } def\Hy@ps@CR
    /H.R {%
      currentpoint %
      HyperBorder sub /pdf@ury exch def %
      HyperBorder add /pdf@urx exch def %
      currentpoint exch pop vsize 72 sub %
      exch DvipsToPDF sub /pdf@voff exch def%
    } def\Hy@ps@CR
  }%
}
\def\setpdflinkmargin#1{%
  \begingroup
    \setlength{\dimen@}{#1}%
    \literalps@out{%
      /HyperBorder{\strip@pt\dimen@\space PDFToDvips}def%
    }%
  \endgroup
}
\Hy@AtBeginDocument{%
  \ifHy@colorlinks
    \headerps@out{/PDFBorder{/Border [0 0 0]}def}%
  \fi
}
\expandafter\let\expandafter\keepPDF@SetupDoc
  \csname PDF@SetupDoc\endcsname
\def\PDF@SetupDoc{%
  \ifx\@baseurl\@empty
  \else
    \special{html:<base href="\@baseurl">}%
  \fi
  \keepPDF@SetupDoc
}
\Hy@WrapperDef\hyper@anchor#1{%
  \Hy@SaveLastskip
  \Hy@VerboseAnchor{#1}%
  \begingroup
    \let\protect=\string
    \special{html:<a name=%
        \hyper@quote\HyperDestNameFilter{#1}\hyper@quote>}%
  \endgroup
  \Hy@activeanchortrue
  \Hy@colorlink\@anchorcolor\anchor@spot\Hy@endcolorlink
  \special{html:</a>}%
  \Hy@activeanchorfalse
  \Hy@RestoreLastskip
}
\Hy@WrapperDef\hyper@anchorstart#1{%
  \Hy@SaveLastskip
  \Hy@VerboseAnchor{#1}%
  \begingroup
    \hyper@chars
    \special{html:<a name=%
        \hyper@quote\HyperDestNameFilter{#1}\hyper@quote>}%
  \endgroup
  \Hy@activeanchortrue
}
\def\hyper@anchorend{%
  \special{html:</a>}%
  \Hy@activeanchorfalse
  \Hy@RestoreLastskip
}
\def\@urltype{url}
\def\hyper@linkstart#1#2{%
  \Hy@VerboseLinkStart{#1}{#2}%
  \expandafter\Hy@colorlink\csname @#1color\endcsname
  \def\Hy@tempa{#1}%
  \ifx\Hy@tempa\@urltype
    \special{html:<a href=\hyper@quote#2\hyper@quote>}%
  \else
    \begingroup
      \hyper@chars
      \special{%
        html:<a href=%
        \hyper@quote\#\HyperDestNameFilter{#2}\hyper@quote>%
      }%
    \endgroup
  \fi
}
\def\hyper@linkend{%
  \special{html:</a>}%
  \Hy@endcolorlink
}
\def\hyper@linkfile#1#2#3{%
  \hyper@linkurl{#1}{%
    \Hy@linkfileprefix#2\ifx\\#3\\\else\##3\fi
  }%
}
\def\hyper@linkurl#1#2{%
  \leavevmode
  \ifHy@raiselinks
    \Hy@SaveSpaceFactor
    \Hy@SaveSavedSpaceFactor
    \sbox\@tempboxa{\Hy@RestoreSpaceFactor#1}%
    \Hy@RestoreSavedSpaceFactor
    \@linkdim\dp\@tempboxa
    \lower\@linkdim\hbox{%
      \hyper@chars
      \special{html:<a href=\hyper@quote#2\hyper@quote>}%
    }%
    \Hy@colorlink\@urlcolor
      \Hy@RestoreSpaceFactor
      #1\Hy@xspace@end
      \Hy@SaveSpaceFactor
      \@linkdim\ht\@tempboxa
      \advance\@linkdim by -6.5\p@
      \raise\@linkdim\hbox{\special{html:</a>}}%
    \Hy@endcolorlink
    \Hy@RestoreSpaceFactor
  \else
    \begingroup
      \hyper@chars
      \special{html:<a href=\hyper@quote#2\hyper@quote>}%
      \Hy@colorlink\@urlcolor#1\Hy@xspace@end
      \special{html:</a>}%
      \Hy@endcolorlink
    \endgroup
  \fi
}
\def\hyper@link#1#2#3{%
  \Hy@VerboseLinkStart{#1}{#2}%
  \hyper@linkurl{#3}{\#\HyperDestNameFilter{#2}}%
}
\def\hyper@image#1#2{%
  \begingroup
    \hyper@chars
    \special{html:<img src=\hyper@quote#1\hyper@quote>}%
  \endgroup
}
\endinput
%%
%% End of file `htexture.def'.
