%%
%% This is file `puarenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref.dtx  (with options: `puarenc')
%% 
%% Copyright
%% 1995-2001 Sebastian Rahtz, with portions written by David Carlisle and Heiko Oberdiek
%% 2001-2015 Heiko Oberdiek
%% 2016-2019 Oberdiek Package Support Group
%% 2019-2026 LaTeX Project
%%      https://github.com/latex3/hyperref/issues
%% 
%% This file is part of the `Hyperref Bundle'.
%% -------------------------------------------
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status `maintained'.
%% 
%% The Current Maintainer of this work is the LaTeX Project.
%% 
%% The list of all files belonging to the `Hyperref Bundle' is
%% given in the file `manifest.txt'.
%% 
%% File: hyperref.dtx
\ProvidesFile{puarenc.def}
  [2026-01-29 v7.01p %
  Hyperref: Additions to puenc.def for Arabi]
\DeclareTextCommand{\hamza}{PU}{\86\041}% U+0621
\DeclareTextCommand{\alefmadda}{PU}{\86\042}% U+0622
\DeclareTextCommand{\alefhamza}{PU}{\86\043}% U+0623
\DeclareTextCommand{\wawhamza}{PU}{\86\044}% U+0624
\DeclareTextCommand{\aleflowerhamza}{PU}{\86\045}% U+0625
\DeclareTextCommand{\yahamza}{PU}{\86\046}% U+0626
\DeclareTextCommand{\alef}{PU}{\86\047}% U+0627
\DeclareTextCommand{\baa}{PU}{\86\050}% U+0628
\DeclareTextCommand{\T}{PU}{\86\051}% U+0629
\DeclareTextCommand{\taa}{PU}{\86\052}% U+062A
\DeclareTextCommand{\thaa}{PU}{\86\053}% U+062B
\DeclareTextCommand{\jeem}{PU}{\86\054}% U+062C
\DeclareTextCommand{\Haa}{PU}{\86\055}% U+062D
\DeclareTextCommand{\kha}{PU}{\86\056}% U+062E
\DeclareTextCommand{\dal}{PU}{\86\057}% U+062F
\DeclareTextCommand{\dhal}{PU}{\86\060}% U+0630
\DeclareTextCommand{\ra}{PU}{\86\061}% U+0631
\DeclareTextCommand{\zay}{PU}{\86\062}% U+0632
\DeclareTextCommand{\seen}{PU}{\86\063}% U+0633
\DeclareTextCommand{\sheen}{PU}{\86\064}% U+0634
\DeclareTextCommand{\sad}{PU}{\86\065}% U+0635
\DeclareTextCommand{\dad}{PU}{\86\066}% U+0636
\DeclareTextCommand{\Ta}{PU}{\86\067}% U+0637
\DeclareTextCommand{\za}{PU}{\86\070}% U+0638
\DeclareTextCommand{\ayn}{PU}{\86\071}% U+0639
\DeclareTextCommand{\ghayn}{PU}{\86\072}% U+063A
\DeclareTextCommand{\tatweel}{PU}{\86\100}% U+0640
\DeclareTextCommand{\fa}{PU}{\86\101}% U+0641
\DeclareTextCommand{\qaf}{PU}{\86\102}% U+0642
\DeclareTextCommand{\kaf}{PU}{\86\103}% U+0643
\DeclareTextCommand{\lam}{PU}{\86\104}% U+0644
\DeclareTextCommand{\meem}{PU}{\86\105}% U+0645
\DeclareTextCommand{\nun}{PU}{\86\106}% U+0646
\DeclareTextCommand{\ha}{PU}{\86\107}% U+0647
\DeclareTextCommand{\waw}{PU}{\86\110}% U+0648
\DeclareTextCommand{\alefmaqsura}{PU}{\86\111}% U+0649
\DeclareTextCommand{\ya}{PU}{\86\112}% U+064A
\DeclareTextCommand{\nasb}{PU}{\86\113}% U+064B
\DeclareTextCommand{\raff}{PU}{\86\114}% U+064C
\DeclareTextCommand{\jarr}{PU}{\86\115}% U+064D
\DeclareTextCommand{\fatha}{PU}{\86\116}% U+064E
\DeclareTextCommand{\damma}{PU}{\86\117}% U+064F
\DeclareTextCommand{\kasra}{PU}{\86\120}% U+0650
\DeclareTextCommand{\shadda}{PU}{\86\121}% U+0651
\DeclareTextCommand{\sukun}{PU}{\86\122}% U+0652
\DeclareTextCommand{\peh}{PU}{\86\176}% U+067E
\DeclareTextCommand{\tcheh}{PU}{\86\206}% U+0686
\DeclareTextCommand{\jeh}{PU}{\86\230}% U+0698
\DeclareTextCommand{\farsikaf}{PU}{\86\251}% U+06A9
\DeclareTextCommand{\gaf}{PU}{\86\257}% U+06AF
\DeclareTextCommand{\farsiya}{PU}{\86\314}% U+06CC
\DeclareTextCommand{\ZWNJ}{PU}{\9040\014}% U+200C
\DeclareTextCommand{\textEncodingNoboundary}{PU}{\9040\015}% U+200D
\endinput
%%
%% End of file `puarenc.def'.
