%%
%% This is file `cp1252.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenc.dtx  (with options: `cp1252')
%% 
%% This is a generated file.
%% 
%% The source is maintained by the LaTeX Project team and bug
%% reports for it can be opened at https://latex-project.org/bugs.html
%% (but please observe conditions on bug reports sent to that address!)
%% 
%% 
%% Copyright (C) 1993-2025
%% The LaTeX Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the LaTeX base system.
%% --------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2008 or later.
%% 
%% This file has the LPPL maintenance status "maintained".
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% base system. You may however distribute the LaTeX base system without
%% such generated files.
%% 
%% The list of all files belonging to the LaTeX base distribution is
%% given in the file `manifest.txt'. See also `legal.txt' for additional
%% information.
%% 
%% The list of derived (unpacked) files belonging to the distribution
%% and covered by LPPL is defined by the unpacking scripts (with
%% extension .ins) which are part of the distribution.

  \ProvidesFile{cp1252.def}
   [2024/02/08 v1.3d Input encoding file]
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\textonehalf}{\ensuremath{\frac12}}
\ProvideTextCommandDefault{\textonequarter}{\ensuremath{\frac14}}
\ProvideTextCommandDefault{\textthreequarters}{\ensuremath{\frac34}}
\ProvideTextCommandDefault{\textflorin}{\textit{f}}
\ProvideTextCommandDefault{\textcent}
   {\TextSymbolUnavailable\textcent}
\ProvideTextCommandDefault{\textyen}
   {\TextSymbolUnavailable\textyen}
\ProvideTextCommandDefault{\texteuro}
   {\TextSymbolUnavailable\texteuro}
\ProvideTextCommandDefault{\textcurrency}
   {\TextSymbolUnavailable\textcurrency}
\ProvideTextCommandDefault{\textbrokenbar}
   {\TextSymbolUnavailable\textbrokenbar}
\ProvideTextCommandDefault{\textperthousand}
   {\TextSymbolUnavailable\textperthousand}
\providecommand{\mathonesuperior}{{^1}}
\providecommand{\maththreesuperior}{{^3}}
\providecommand{\mathtwosuperior}{{^2}}
\DeclareInputText{128}{\texteuro}
\DeclareInputText{130}{\quotesinglbase}
\DeclareInputText{131}{\textflorin}
\DeclareInputText{132}{\quotedblbase}
\DeclareInputText{133}{\dots}
\DeclareInputText{134}{\dag}
\DeclareInputText{135}{\ddag}
\DeclareInputText{136}{\^{}}
\DeclareInputText{137}{\textperthousand}
\DeclareInputText{138}{\v S}
\DeclareInputText{139}{\guilsinglleft}
\DeclareInputText{140}{\OE}
\DeclareInputText{142}{\v Z}
\DeclareInputText{145}{\textquoteleft}
\DeclareInputText{146}{\textquoteright}
\DeclareInputText{147}{\textquotedblleft}
\DeclareInputText{148}{\textquotedblright}
\DeclareInputText{149}{\textbullet}
\DeclareInputText{150}{\textendash}
\DeclareInputText{151}{\textemdash}
\DeclareInputText{152}{\~{}}
\DeclareInputText{153}{\texttrademark}
\DeclareInputText{154}{\v s}
\DeclareInputText{155}{\guilsinglright}
\DeclareInputText{156}{\oe}
\DeclareInputText{158}{\v z}
\DeclareInputText{159}{\"Y}
\DeclareInputText{164}{\textcurrency}
\DeclareInputText{166}{\textbrokenbar}
\DeclareInputText{168}{\"{}}
\DeclareInputText{180}{\@tabacckludge'{}}
\DeclareInputText{184}{\c\ }
\DeclareInputText{188}{\textonequarter}
\DeclareInputText{189}{\textonehalf}
\DeclareInputText{190}{\textthreequarters}
\DeclareInputText{160}{\nobreakspace}
\DeclareInputText{176}{\textdegree}
\DeclareInputText{161}{\textexclamdown}
\DeclareInputMath{177}{\pm}
\DeclareInputText{162}{\textcent}
\DeclareInputMath{178}{\mathtwosuperior}
\DeclareInputText{163}{\pounds}
\DeclareInputMath{179}{\maththreesuperior}
\DeclareInputText{165}{\textyen}
\DeclareInputMath{181}{\mu}
\DeclareInputText{182}{\P}
\DeclareInputText{167}{\S}
\DeclareInputText{183}{\textperiodcentered}
\DeclareInputText{169}{\copyright}
\DeclareInputMath{185}{\mathonesuperior}
\DeclareInputText{170}{\textordfeminine}
\DeclareInputText{186}{\textordmasculine}
\DeclareInputText{171}{\guillemetleft}
\DeclareInputText{187}{\guillemetright}
\DeclareInputMath{172}{\lnot}
\DeclareInputText{173}{\-}
\DeclareInputText{174}{\textregistered}
\DeclareInputText{175}{\@tabacckludge={}}
\DeclareInputText{191}{\textquestiondown}
\DeclareInputText{192}{\@tabacckludge`A}
\DeclareInputText{208}{\DH}
\DeclareInputText{193}{\@tabacckludge'A}
\DeclareInputText{209}{\~N}
\DeclareInputText{194}{\^A}
\DeclareInputText{210}{\@tabacckludge`O}
\DeclareInputText{195}{\~A}
\DeclareInputText{211}{\@tabacckludge'O}
\DeclareInputText{196}{\"A}
\DeclareInputText{212}{\^O}
\DeclareInputText{197}{\r A}
\DeclareInputText{213}{\~O}
\DeclareInputText{198}{\AE}
\DeclareInputText{214}{\"O}
\DeclareInputText{199}{\c C}
\DeclareInputMath{215}{\times}
\DeclareInputText{200}{\@tabacckludge`E}
\DeclareInputText{216}{\O}
\DeclareInputText{201}{\@tabacckludge'E}
\DeclareInputText{217}{\@tabacckludge`U}
\DeclareInputText{202}{\^E}
\DeclareInputText{218}{\@tabacckludge'U}
\DeclareInputText{203}{\"E}
\DeclareInputText{219}{\^U}
\DeclareInputText{204}{\@tabacckludge`I}
\DeclareInputText{220}{\"U}
\DeclareInputText{205}{\@tabacckludge'I}
\DeclareInputText{221}{\@tabacckludge'Y}
\DeclareInputText{206}{\^I}
\DeclareInputText{222}{\TH}
\DeclareInputText{207}{\"I}
\DeclareInputText{223}{\ss}
\DeclareInputText{224}{\@tabacckludge`a}
\DeclareInputText{240}{\dh}
\DeclareInputText{225}{\@tabacckludge'a}
\DeclareInputText{241}{\~n}
\DeclareInputText{226}{\^a}
\DeclareInputText{242}{\@tabacckludge`o}
\DeclareInputText{227}{\~a}
\DeclareInputText{243}{\@tabacckludge'o}
\DeclareInputText{228}{\"a}
\DeclareInputText{244}{\^o}
\DeclareInputText{229}{\r a}
\DeclareInputText{245}{\~o}
\DeclareInputText{230}{\ae}
\DeclareInputText{246}{\"o}
\DeclareInputText{231}{\c c}
\DeclareInputMath{247}{\div}
\DeclareInputText{232}{\@tabacckludge`e}
\DeclareInputText{248}{\o}
\DeclareInputText{233}{\@tabacckludge'e}
\DeclareInputText{249}{\@tabacckludge`u}
\DeclareInputText{234}{\^e}
\DeclareInputText{250}{\@tabacckludge'u}
\DeclareInputText{235}{\"e}
\DeclareInputText{251}{\^u}
\DeclareInputText{236}{\@tabacckludge`\i}
\DeclareInputText{252}{\"u}
\DeclareInputText{237}{\@tabacckludge'\i}
\DeclareInputText{253}{\@tabacckludge'y}
\DeclareInputText{238}{\^\i}
\DeclareInputText{254}{\th}
\DeclareInputText{239}{\"\i}
\DeclareInputText{255}{\"y}
\endinput
%%
%% End of file `cp1252.def'.
