%%
%% This is file `pd1enc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref.dtx  (with options: `pd1enc')
%% 
%% Copyright
%% 1995-2001 Sebastian Rahtz, with portions written by David Carlisle and Heiko Oberdiek
%% 2001-2015 Heiko Oberdiek
%% 2016-2019 Oberdiek Package Support Group
%% 2019-2026 LaTeX Project
%%      https://github.com/latex3/hyperref/issues
%% 
%% This file is part of the `Hyperref Bundle'.
%% -------------------------------------------
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status `maintained'.
%% 
%% The Current Maintainer of this work is the LaTeX Project.
%% 
%% The list of all files belonging to the `Hyperref Bundle' is
%% given in the file `manifest.txt'.
%% 
%% File: hyperref.dtx
\ProvidesFile{pd1enc.def}
  [2026-01-29 v7.01p %
  Hyperref: PDFDocEncoding definition (HO)]
\DeclareFontEncoding{PD1}{}{}
\DeclareTextAccent{\`}{PD1}{\textasciigrave}
\DeclareTextAccent{\'}{PD1}{\textacute}
\DeclareTextAccent{\^}{PD1}{\textasciicircum}
\DeclareTextAccent{\~}{PD1}{\texttilde}
\DeclareTextAccent{\"}{PD1}{\textasciidieresis}
\DeclareTextAccent{\r}{PD1}{\textring}
\DeclareTextAccent{\v}{PD1}{\textasciicaron}
\DeclareTextAccent{\.}{PD1}{\textdotaccent}
\DeclareTextAccent{\c}{PD1}{\textcedilla}
\DeclareTextAccent{\=}{PD1}{\textasciimacron}
\DeclareTextAccent{\b}{PD1}{\textmacronbelow}
\DeclareTextAccent{\d}{PD1}{\textdotbelow}
\DeclareTextCompositeCommand{\`}{PD1}{\@empty}{\textasciigrave}
\DeclareTextCompositeCommand{\'}{PD1}{\@empty}{\textacute}
\DeclareTextCompositeCommand{\^}{PD1}{\@empty}{\textasciicircum}
\DeclareTextCompositeCommand{\~}{PD1}{\@empty}{\texttilde}
\DeclareTextCompositeCommand{\"}{PD1}{\@empty}{\textasciidieresis}
\DeclareTextCompositeCommand{\r}{PD1}{\@empty}{\textring}
\DeclareTextCompositeCommand{\v}{PD1}{\@empty}{\textasciicaron}
\DeclareTextCompositeCommand{\.}{PD1}{\@empty}{\textdotaccent}
\DeclareTextCompositeCommand{\c}{PD1}{\@empty}{\textcedilla}
\DeclareTextCompositeCommand{\=}{PD1}{\@empty}{\textasciimacron}
\DeclareTextCompositeCommand{\b}{PD1}{\@empty}{\textmacronbelow}
\DeclareTextCompositeCommand{\d}{PD1}{\@empty}{\textdotbelow}
\DeclareTextCompositeCommand{\`}{PD1}{\ }{\textasciigrave}
\DeclareTextCompositeCommand{\'}{PD1}{\ }{\textacute}
\DeclareTextCompositeCommand{\^}{PD1}{\ }{\textasciicircum}
\DeclareTextCompositeCommand{\~}{PD1}{\ }{\texttilde}
\DeclareTextCompositeCommand{\"}{PD1}{\ }{\textasciidieresis}
\DeclareTextCompositeCommand{\r}{PD1}{\ }{\textring}
\DeclareTextCompositeCommand{\v}{PD1}{\ }{\textasciicaron}
\DeclareTextCompositeCommand{\.}{PD1}{\ }{\textdotaccent}
\DeclareTextCompositeCommand{\c}{PD1}{\ }{\textcedilla}
\DeclareTextCompositeCommand{\=}{PD1}{\ }{\textasciimacron}
\DeclareTextCompositeCommand{\b}{PD1}{\ }{\textmacronbelow}
\DeclareTextCompositeCommand{\d}{PD1}{\ }{\textdotbelow}
\DeclareTextCommand{\k}{PD1}[1]{\TextSymbolUnavailable{\k{#1}}#1}
\DeclareTextCommand{\t}{PD1}[1]{\TextSymbolUnavailable{\t{#1}}#1}
\DeclareTextCommand{\newtie}{PD1}[1]{%
  \TextSymbolUnavailable{\newtie{#1}}#1%
}
\DeclareTextCommand{\textHT}{PD1}{\011}% U+0009
\DeclareTextCommand{\textLF}{PD1}{\012}% U+000A
\DeclareTextCommand{\textCR}{PD1}{\015}% U+000D
\DeclareTextCommand{\textasciibreve}{PD1}{\030}% U+02D8
\DeclareTextCommand{\textasciicaron}{PD1}{\031}% U+02C7
\DeclareTextCommand{\textcircumflex}{PD1}{\032}% U+02C6
\DeclareTextCommand{\textdotaccent}{PD1}{\033}% U+02D9
\DeclareTextCommand{\texthungarumlaut}{PD1}{\034}% U+02DD
\DeclareTextCommand{\textogonek}{PD1}{\035}% U+02DB
\DeclareTextCommand{\textring}{PD1}{\036}% U+02DA
\DeclareTextCommand{\texttilde}{PD1}{\037}% U+02DC
\DeclareTextCommand{\textquotedbl}{PD1}{"}% \042 U+0022
\DeclareTextCommand{\textnumbersign}{PD1}{\043}% U+0023
\DeclareTextCommand{\textdollar}{PD1}{\044}% U+0024
\DeclareTextCommand{\textpercent}{PD1}{\045}% U+0025
\DeclareTextCommand{\textampersand}{PD1}{\046}% U+0026
\DeclareTextCommand{\textparenleft}{PD1}{\string\(}% \050 U+0028
\DeclareTextCommand{\textparenright}{PD1}{\string\)}% \051 U+0029
\DeclareTextCommand{\textdotbelow}{PD1}{.}% \056 U+002E
\DeclareTextCommand{\textless}{PD1}{<}% \074 U+003C
\DeclareTextCommand{\textgreater}{PD1}{>}% \076 U+003E
\DeclareTextCommand{\textbackslash}{PD1}{\134}% U+005C
\DeclareTextCommand{\textsetminus}{PD1}{\textbackslash}
\DeclareTextCommand{\textasciicircum}{PD1}{\136}% U+005E
\DeclareTextCommand{\textunderscore}{PD1}{\137}% U+005F
\DeclareTextCommand{\textmacronbelow}{PD1}{\137}% U+005F
\DeclareTextCommand{\textasciigrave}{PD1}{\140}% U+0060
\DeclareTextCompositeCommand{\.}{PD1}{i}{i}% \151 U+0069
\DeclareTextCommand{\textbraceleft}{PD1}{\173}% U+007B
\DeclareTextCommand{\textbar}{PD1}{|}% U+007C
\DeclareTextCommand{\textbraceright}{PD1}{\175}% U+007D
\DeclareTextCommand{\textasciitilde}{PD1}{\176}% U+007E
\DeclareTextCommand{\textbullet}{PD1}{\200}% U+2022
\DeclareTextCommand{\textdagger}{PD1}{\201}% U+2020
\DeclareTextCommand{\textdaggerdbl}{PD1}{\202}% U+2021
\DeclareTextCommand{\textddagger}{PD1}{\textdaggerdbl}
\DeclareTextCommand{\textellipsis}{PD1}{\203}% U+2026
\DeclareTextCommand{\textemdash}{PD1}{\204}% U+2014
\DeclareTextCommand{\textendash}{PD1}{\205}% U+2013
\DeclareTextCommand{\textflorin}{PD1}{\206}% U+0192
\DeclareTextCommand{\textfractionsolidus}{PD1}{\207}% U+2044
\DeclareTextCommand{\guilsinglleft}{PD1}{\210}% U+2039
\DeclareTextCommand{\guilsinglright}{PD1}{\211}% U+203A
\DeclareTextCommand{\textminus}{PD1}{\212}% U+2212
\DeclareTextCommand{\textperthousand}{PD1}{\213}% U+2030
\DeclareTextCommand{\quotedblbase}{PD1}{\214}% U+201E
\DeclareTextCommand{\textquotedblleft}{PD1}{\215}% U+201C
\DeclareTextCommand{\textquotedblright}{PD1}{\216}% U+201D
\DeclareTextCommand{\textquoteleft}{PD1}{\217}% U+2018
\DeclareTextCommand{\textquoteright}{PD1}{\220}% U+2019
\DeclareTextCommand{\quotesinglbase}{PD1}{\221}% U+201A
\DeclareTextCommand{\texttrademark}{PD1}{\222}% U+2122
\DeclareTextCommand{\textfi}{PD1}{\223}% U+FB01
\DeclareTextCommand{\textfl}{PD1}{\224}% U+FB02
\DeclareTextCommand{\L}{PD1}{\225}% U+0141
\DeclareTextCommand{\OE}{PD1}{\226}% U+0152
\DeclareTextCompositeCommand{\v}{PD1}{S}{\227}% U+0160
\DeclareTextCompositeCommand{\"}{PD1}{Y}{\230}% U+0178
\DeclareTextCommand{\IJ}{PD1}{IJ}% ligature U+0049 U+004A
\DeclareTextCompositeCommand{\v}{PD1}{Z}{\231}% U+017D
\DeclareTextCommand{\i}{PD1}{\232}% U+0131
\DeclareTextCommand{\l}{PD1}{\233}% U+0142
\DeclareTextCommand{\oe}{PD1}{\234}% U+0153
\DeclareTextCompositeCommand{\v}{PD1}{s}{\235}% U+0161
\DeclareTextCompositeCommand{\v}{PD1}{z}{\236}% U+017E
\DeclareTextCommand{\texteuro}{PD1}{\240}% U+20AC
\DeclareTextCommand{\textexclamdown}{PD1}{\241}% U+00A1
\DeclareTextCommand{\textcent}{PD1}{\242}% U+00A2
\DeclareTextCommand{\textsterling}{PD1}{\243}% U+00A3
\DeclareTextCommand{\textcurrency}{PD1}{\244}% U+00A4
\DeclareTextCommand{\textyen}{PD1}{\245}% U+00A5
\DeclareTextCommand{\textbrokenbar}{PD1}{\246}% U+00A6
\DeclareTextCommand{\textsection}{PD1}{\247}% U+00A7
\DeclareTextCommand{\textasciidieresis}{PD1}{\250}% U+00A8
\DeclareTextCommand{\textcopyright}{PD1}{\251}% U+00A9
\DeclareTextCommand{\textordfeminine}{PD1}{\252}% U+00AA
\DeclareTextCommand{\guillemotleft}{PD1}{\253}% U+00AB
\DeclareTextCommand{\guillemetleft}{PD1}{\253}% U+00AB
\DeclareTextCommand{\textlogicalnot}{PD1}{\254}% U+00AC
\DeclareTextCommand{\textlnot}{PD1}{\254}% logical not
\DeclareTextCommand{\textregistered}{PD1}{\256}% U+00AE
\DeclareTextCommand{\textasciimacron}{PD1}{\257}% U+00AF
\DeclareTextCommand{\textdegree}{PD1}{\260}% U+00B0
\DeclareTextCommand{\textplusminus}{PD1}{\261}% U+00B1
\DeclareTextCommand{\texttwosuperior}{PD1}{\262}%* U+00B2
\DeclareTextCommand{\textthreesuperior}{PD1}{\263}%* U+00B3
\DeclareTextCommand{\textacute}{PD1}{\264}% U+00B4
\DeclareTextCommand{\textmu}{PD1}{\265}% U+00B5
\DeclareTextCommand{\textparagraph}{PD1}{\266}% U+00B6
\DeclareTextCommand{\textperiodcentered}{PD1}{\267}% U+00B7
\DeclareTextCommand{\textcedilla}{PD1}{\270}% U+00B8
\DeclareTextCommand{\textonesuperior}{PD1}{\271}%* U+00B9
\DeclareTextCommand{\textordmasculine}{PD1}{\272}% U+00BA
\DeclareTextCommand{\guillemotright}{PD1}{\273}% U+00BB
\DeclareTextCommand{\guillemetright}{PD1}{\273}% U+00BB
\DeclareTextCommand{\textonequarter}{PD1}{\274}% U+00BC
\DeclareTextCommand{\textonehalf}{PD1}{\275}% U+00BD
\DeclareTextCommand{\textthreequarters}{PD1}{\276}% U+00BE
\DeclareTextCommand{\textquestiondown}{PD1}{\277}% U+00BF
\DeclareTextCompositeCommand{\`}{PD1}{A}{\300}% U+00C0
\DeclareTextCompositeCommand{\'}{PD1}{A}{\301}% U+00C1
\DeclareTextCompositeCommand{\^}{PD1}{A}{\302}% U+00C2
\DeclareTextCompositeCommand{\~}{PD1}{A}{\303}% U+00C3
\DeclareTextCompositeCommand{\"}{PD1}{A}{\304}% U+00C4
\DeclareTextCompositeCommand{\r}{PD1}{A}{\305}% U+00C5
\DeclareTextCommand{\AE}{PD1}{\306}% U+00C6
\DeclareTextCompositeCommand{\c}{PD1}{C}{\307}% U+00C7
\DeclareTextCompositeCommand{\`}{PD1}{E}{\310}% U+00C8
\DeclareTextCompositeCommand{\'}{PD1}{E}{\311}% U+00C9
\DeclareTextCompositeCommand{\^}{PD1}{E}{\312}% U+00CA
\DeclareTextCompositeCommand{\"}{PD1}{E}{\313}% U+00CB
\DeclareTextCompositeCommand{\`}{PD1}{I}{\314}% U+00CC
\DeclareTextCompositeCommand{\'}{PD1}{I}{\315}% U+00CD
\DeclareTextCompositeCommand{\^}{PD1}{I}{\316}% U+00CE
\DeclareTextCompositeCommand{\"}{PD1}{I}{\317}% U+00CF
\DeclareTextCommand{\DH}{PD1}{\320}% U+00D0
\DeclareTextCommand{\DJ}{PD1}{\320}% U+00D0
\DeclareTextCompositeCommand{\~}{PD1}{N}{\321}% U+00D1
\DeclareTextCompositeCommand{\`}{PD1}{O}{\322}% U+00D2
\DeclareTextCompositeCommand{\'}{PD1}{O}{\323}% U+00D3
\DeclareTextCompositeCommand{\^}{PD1}{O}{\324}% U+00D4
\DeclareTextCompositeCommand{\~}{PD1}{O}{\325}% U+00D5
\DeclareTextCompositeCommand{\"}{PD1}{O}{\326}% U+00D6
\DeclareTextCommand{\textmultiply}{PD1}{\327}% U+00D7
\DeclareTextCommand{\O}{PD1}{\330}% U+00D8
\DeclareTextCompositeCommand{\`}{PD1}{U}{\331}% U+00D9
\DeclareTextCompositeCommand{\'}{PD1}{U}{\332}% U+00DA
\DeclareTextCompositeCommand{\^}{PD1}{U}{\333}% U+00DB
\DeclareTextCompositeCommand{\"}{PD1}{U}{\334}% U+00DC
\DeclareTextCompositeCommand{\'}{PD1}{Y}{\335}% U+00DD
\DeclareTextCommand{\TH}{PD1}{\336}% U+00DE
\DeclareTextCommand{\textThorn}{PD1}{\336}%* U+00DE
\DeclareTextCommand{\ss}{PD1}{\337}% U+00DF
\DeclareTextCompositeCommand{\`}{PD1}{a}{\340}% U+00E0
\DeclareTextCompositeCommand{\'}{PD1}{a}{\341}% U+00E1
\DeclareTextCompositeCommand{\^}{PD1}{a}{\342}% U+00E2
\DeclareTextCompositeCommand{\~}{PD1}{a}{\343}% U+00E3
\DeclareTextCompositeCommand{\"}{PD1}{a}{\344}% U+00E4
\DeclareTextCompositeCommand{\r}{PD1}{a}{\345}% U+00E5
\DeclareTextCommand{\ae}{PD1}{\346}% U+00E6
\DeclareTextCompositeCommand{\c}{PD1}{c}{\347}% U+00E7
\DeclareTextCompositeCommand{\`}{PD1}{e}{\350}% U+00E8
\DeclareTextCompositeCommand{\'}{PD1}{e}{\351}% U+00E9
\DeclareTextCompositeCommand{\^}{PD1}{e}{\352}% U+00EA
\DeclareTextCompositeCommand{\"}{PD1}{e}{\353}% U+00EB
\DeclareTextCompositeCommand{\`}{PD1}{i}{\354}% U+00EC
\DeclareTextCompositeCommand{\`}{PD1}{\i}{\354}% U+00EC
\DeclareTextCompositeCommand{\'}{PD1}{i}{\355}% U+00ED
\DeclareTextCompositeCommand{\'}{PD1}{\i}{\355}% U+00ED
\DeclareTextCompositeCommand{\^}{PD1}{i}{\356}% U+00EE
\DeclareTextCompositeCommand{\^}{PD1}{\i}{\356}% U+00EE
\DeclareTextCompositeCommand{\"}{PD1}{i}{\357}% U+00EF
\DeclareTextCompositeCommand{\"}{PD1}{\i}{\357}% U+00EF
\DeclareTextCommand{\dh}{PD1}{\360}% U+00F0
\DeclareTextCompositeCommand{\~}{PD1}{n}{\361}% U+00F1
\DeclareTextCompositeCommand{\`}{PD1}{o}{\362}% U+00F2
\DeclareTextCompositeCommand{\'}{PD1}{o}{\363}% U+00F3
\DeclareTextCompositeCommand{\^}{PD1}{o}{\364}% U+00F4
\DeclareTextCompositeCommand{\~}{PD1}{o}{\365}% U+00F5
\DeclareTextCompositeCommand{\"}{PD1}{o}{\366}% U+00F6
\DeclareTextCommand{\textdivide}{PD1}{\367}% U+00F7
\DeclareTextCommand{\o}{PD1}{\370}% U+00F8
\DeclareTextCompositeCommand{\`}{PD1}{u}{\371}% U+00F9
\DeclareTextCompositeCommand{\'}{PD1}{u}{\372}% U+00FA
\DeclareTextCompositeCommand{\^}{PD1}{u}{\373}% U+00FB
\DeclareTextCompositeCommand{\"}{PD1}{u}{\374}% U+00FC
\DeclareTextCompositeCommand{\'}{PD1}{y}{\375}% U+00FD
\DeclareTextCommand{\th}{PD1}{\376}% U+00FE
\DeclareTextCommand{\textthorn}{PD1}{\376}%* U+00FE
\DeclareTextCompositeCommand{\"}{PD1}{y}{\377}% U+00FF
\DeclareTextCommand{\ij}{PD1}{ij}% ligature U+0069 U+006A
\DeclareTextCommand{\SS}{PD1}{SS}%
\DeclareTextCommand{\textcelsius}{PD1}{\textdegree C}%
\DeclareTextCommand{\textglqq}{PD1}{\quotedblbase}%
\DeclareTextCommand{\textgrqq}{PD1}{\textquotedblleft}%
\DeclareTextCommand{\textglq}{PD1}{\quotesinglbase}%
\DeclareTextCommand{\textgrq}{PD1}{\textquoteleft}%
\DeclareTextCommand{\textflqq}{PD1}{\guillemetleft}%
\DeclareTextCommand{\textfrqq}{PD1}{\guillemetright}%
\DeclareTextCommand{\textflq}{PD1}{\guilsinglleft}%
\DeclareTextCommand{\textfrq}{PD1}{\guilsinglright}%
\DeclareTextCommand{\textneg}{PD1}{\textlogicalnot}%
\DeclareTextCommand{\texttimes}{PD1}{\textmultiply}%
\DeclareTextCommand{\textdiv}{PD1}{\textdivide}%
\DeclareTextCommand{\textpm}{PD1}{\textplusminus}%
\DeclareTextCommand{\textcdot}{PD1}{\textperiodcentered}%
\DeclareTextCommand{\textbeta}{PD1}{\ss}%
\DeclareTextCompositeCommand{\k}{PD1}{a}{a}% aogonek
\DeclareTextCompositeCommand{\'}{PD1}{c}{c}% cacute
\DeclareTextCompositeCommand{\k}{PD1}{e}{e}% eogonek
\DeclareTextCompositeCommand{\'}{PD1}{n}{n}% nacute
\DeclareTextCompositeCommand{\'}{PD1}{s}{s}% sacute
\DeclareTextCompositeCommand{\'}{PD1}{z}{z}% zacute
\DeclareTextCompositeCommand{\.}{PD1}{z}{z}% zdot
\DeclareTextCompositeCommand{\k}{PD1}{A}{A}% Aogonek
\DeclareTextCompositeCommand{\'}{PD1}{C}{C}% Cacute
\DeclareTextCompositeCommand{\k}{PD1}{E}{E}% Eogonek
\DeclareTextCompositeCommand{\'}{PD1}{N}{N}% Nacute
\DeclareTextCompositeCommand{\'}{PD1}{S}{S}% Sacute
\DeclareTextCompositeCommand{\'}{PD1}{Z}{Z}% Zacute
\DeclareTextCompositeCommand{\.}{PD1}{Z}{Z}% Zdot
\endinput
%%
%% End of file `pd1enc.def'.
