%%
%% This is file `puvnenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref.dtx  (with options: `puvnenc')
%% 
%% Copyright
%% 1995-2001 Sebastian Rahtz, with portions written by David Carlisle and Heiko Oberdiek
%% 2001-2015 Heiko Oberdiek
%% 2016-2019 Oberdiek Package Support Group
%% 2019-2026 LaTeX Project
%%      https://github.com/latex3/hyperref/issues
%% 
%% This file is part of the `Hyperref Bundle'.
%% -------------------------------------------
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status `maintained'.
%% 
%% The Current Maintainer of this work is the LaTeX Project.
%% 
%% The list of all files belonging to the `Hyperref Bundle' is
%% given in the file `manifest.txt'.
%% 
%% File: hyperref.dtx
\ProvidesFile{puvnenc.def}
  [2026-01-29 v7.01p %
  Hyperref: Additions to puenc.def for VnTeX]
\DeclareTextCommand{\abreve}{PU}{\81\003}% U+0103
\DeclareTextCommand{\acircumflex}{PU}{\80\342}% U+00E2
\DeclareTextCommand{\ecircumflex}{PU}{\80\352}% U+00EA
\DeclareTextCommand{\ocircumflex}{PU}{\80\364}% U+00F4
\DeclareTextCommand{\ohorn}{PU}{\81\241}% U+01A1
\DeclareTextCommand{\uhorn}{PU}{\81\260}% U+01B0
\DeclareTextCommand{\ABREVE}{PU}{\81\002}% U+0102
\DeclareTextCommand{\ACIRCUMFLEX}{PU}{\80\302}% U+00C2
\DeclareTextCommand{\ECIRCUMFLEX}{PU}{\80\312}% U+00CA
\DeclareTextCommand{\OCIRCUMFLEX}{PU}{\80\324}% U+00D4
\DeclareTextCommand{\OHORN}{PU}{\81\240}% U+01A0
\DeclareTextCommand{\UHORN}{PU}{\81\257}% U+01AF
\DeclareTextCompositeCommand{\'}{PU}{a}{\80\341}% U+00E1
\DeclareTextCompositeCommand{\d}{PU}{a}{\9036\241}% U+1EA1
\DeclareTextCompositeCommand{\`}{PU}{a}{\80\340}% U+00E0
\DeclareTextCompositeCommand{\h}{PU}{a}{\9036\243}% U+1EA3
\DeclareTextCompositeCommand{\~}{PU}{a}{\80\343}% U+00E3
\DeclareTextCompositeCommand{\'}{PU}{\abreve}{\9036\257}% U+1EAF
\DeclareTextCompositeCommand{\d}{PU}{\abreve}{\9036\267}% U+1EB7
\DeclareTextCompositeCommand{\`}{PU}{\abreve}{\9036\261}% U+1EB1
\DeclareTextCompositeCommand{\h}{PU}{\abreve}{\9036\263}% U+1EB3
\DeclareTextCompositeCommand{\~}{PU}{\abreve}{\9036\265}% U+1EB5
\DeclareTextCompositeCommand{\'}{PU}{\acircumflex}{\9036\245}% U+1EA5
\DeclareTextCompositeCommand{\d}{PU}{\acircumflex}{\9036\255}% U+1EAD
\DeclareTextCompositeCommand{\`}{PU}{\acircumflex}{\9036\247}% U+1EA7
\DeclareTextCompositeCommand{\h}{PU}{\acircumflex}{\9036\251}% U+1EA9
\DeclareTextCompositeCommand{\~}{PU}{\acircumflex}{\9036\253}% U+1EAB
\DeclareTextCompositeCommand{\'}{PU}{e}{\80\351}% U+00E9
\DeclareTextCompositeCommand{\d}{PU}{e}{\9036\271}% U+1EB9
\DeclareTextCompositeCommand{\`}{PU}{e}{\80\350}% U+00E8
\DeclareTextCompositeCommand{\h}{PU}{e}{\9036\273}% U+1EBB
\DeclareTextCompositeCommand{\~}{PU}{e}{\9036\275}% U+1EBD
\DeclareTextCompositeCommand{\'}{PU}{\ecircumflex}{\9036\277}% U+1EBF
\DeclareTextCompositeCommand{\d}{PU}{\ecircumflex}{\9036\307}% U+1EC7
\DeclareTextCompositeCommand{\`}{PU}{\ecircumflex}{\9036\301}% U+1EC1
\DeclareTextCompositeCommand{\h}{PU}{\ecircumflex}{\9036\303}% U+1EC3
\DeclareTextCompositeCommand{\~}{PU}{\ecircumflex}{\9036\305}% U+1EC5
\DeclareTextCompositeCommand{\'}{PU}{i}{\80\355}% U+00ED
\DeclareTextCompositeCommand{\d}{PU}{i}{\9036\313}% U+1ECB
\DeclareTextCompositeCommand{\`}{PU}{i}{\80\354}% U+00EC
\DeclareTextCompositeCommand{\h}{PU}{i}{\9036\311}% U+1EC9
\DeclareTextCompositeCommand{\~}{PU}{i}{\81\051}% U+0129
\DeclareTextCompositeCommand{\'}{PU}{o}{\80\363}% U+00F3
\DeclareTextCompositeCommand{\d}{PU}{o}{\9036\315}% U+1ECD
\DeclareTextCompositeCommand{\`}{PU}{o}{\80\362}% U+00F2
\DeclareTextCompositeCommand{\h}{PU}{o}{\9036\317}% U+1ECF
\DeclareTextCompositeCommand{\~}{PU}{o}{\80\365}% U+00F5
\DeclareTextCompositeCommand{\'}{PU}{\ocircumflex}{\9036\321}% U+1ED1
\DeclareTextCompositeCommand{\d}{PU}{\ocircumflex}{\9036\331}% U+1ED9
\DeclareTextCompositeCommand{\`}{PU}{\ocircumflex}{\9036\323}% U+1ED3
\DeclareTextCompositeCommand{\h}{PU}{\ocircumflex}{\9036\325}% U+1ED5
\DeclareTextCompositeCommand{\~}{PU}{\ocircumflex}{\9036\327}% U+1ED7
\DeclareTextCompositeCommand{\'}{PU}{\ohorn}{\9036\333}% U+1EDB
\DeclareTextCompositeCommand{\d}{PU}{\ohorn}{\9036\343}% U+1EE3
\DeclareTextCompositeCommand{\`}{PU}{\ohorn}{\9036\335}% U+1EDD
\DeclareTextCompositeCommand{\h}{PU}{\ohorn}{\9036\337}% U+1EDF
\DeclareTextCompositeCommand{\~}{PU}{\ohorn}{\9036\341}% U+1EE1
\DeclareTextCompositeCommand{\'}{PU}{u}{\80\372}% U+00FA
\DeclareTextCompositeCommand{\d}{PU}{u}{\9036\345}% U+1EE5
\DeclareTextCompositeCommand{\`}{PU}{u}{\80\371}% U+00F9
\DeclareTextCompositeCommand{\h}{PU}{u}{\9036\347}% U+1EE7
\DeclareTextCompositeCommand{\~}{PU}{u}{\81\151}% U+0169
\DeclareTextCompositeCommand{\'}{PU}{\uhorn}{\9036\351}% U+1EE9
\DeclareTextCompositeCommand{\d}{PU}{\uhorn}{\9036\361}% U+1EF1
\DeclareTextCompositeCommand{\`}{PU}{\uhorn}{\9036\353}% U+1EEB
\DeclareTextCompositeCommand{\h}{PU}{\uhorn}{\9036\355}% U+1EED
\DeclareTextCompositeCommand{\~}{PU}{\uhorn}{\9036\357}% U+1EEF
\DeclareTextCompositeCommand{\'}{PU}{y}{\80\375}% U+00FD
\DeclareTextCompositeCommand{\d}{PU}{y}{\9036\365}% U+1EF5
\DeclareTextCompositeCommand{\`}{PU}{y}{\9036\363}% U+1EF3
\DeclareTextCompositeCommand{\h}{PU}{y}{\9036\367}% U+1EF7
\DeclareTextCompositeCommand{\~}{PU}{y}{\9036\371}% U+1EF9
\DeclareTextCompositeCommand{\'}{PU}{A}{\80\301}% U+00C1
\DeclareTextCompositeCommand{\d}{PU}{A}{\9036\240}% U+1EA0
\DeclareTextCompositeCommand{\`}{PU}{A}{\80\300}% U+00C0
\DeclareTextCompositeCommand{\h}{PU}{A}{\9036\242}% U+1EA2
\DeclareTextCompositeCommand{\~}{PU}{A}{\80\303}% U+00C3
\DeclareTextCompositeCommand{\'}{PU}{\ABREVE}{\9036\256}% U+1EAE
\DeclareTextCompositeCommand{\d}{PU}{\ABREVE}{\9036\266}% U+1EB6
\DeclareTextCompositeCommand{\`}{PU}{\ABREVE}{\9036\260}% U+1EB0
\DeclareTextCompositeCommand{\h}{PU}{\ABREVE}{\9036\262}% U+1EB2
\DeclareTextCompositeCommand{\~}{PU}{\ABREVE}{\9036\264}% U+1EB4
\DeclareTextCompositeCommand{\'}{PU}{\ACIRCUMFLEX}{\9036\244}% U+1EA4
\DeclareTextCompositeCommand{\d}{PU}{\ACIRCUMFLEX}{\9036\254}% U+1EAC
\DeclareTextCompositeCommand{\`}{PU}{\ACIRCUMFLEX}{\9036\246}% U+1EA6
\DeclareTextCompositeCommand{\h}{PU}{\ACIRCUMFLEX}{\9036\250}% U+1EA8
\DeclareTextCompositeCommand{\~}{PU}{\ACIRCUMFLEX}{\9036\252}% U+1EAA
\DeclareTextCompositeCommand{\'}{PU}{E}{\80\311}% U+00C9
\DeclareTextCompositeCommand{\d}{PU}{E}{\9036\270}% U+1EB8
\DeclareTextCompositeCommand{\`}{PU}{E}{\80\310}% U+00C8
\DeclareTextCompositeCommand{\h}{PU}{E}{\9036\272}% U+1EBA
\DeclareTextCompositeCommand{\~}{PU}{E}{\9036\274}% U+1EBC
\DeclareTextCompositeCommand{\'}{PU}{\ECIRCUMFLEX}{\9036\276}% U+1EBE
\DeclareTextCompositeCommand{\d}{PU}{\ECIRCUMFLEX}{\9036\306}% U+1EC6
\DeclareTextCompositeCommand{\`}{PU}{\ECIRCUMFLEX}{\9036\300}% U+1EC0
\DeclareTextCompositeCommand{\h}{PU}{\ECIRCUMFLEX}{\9036\302}% U+1EC2
\DeclareTextCompositeCommand{\~}{PU}{\ECIRCUMFLEX}{\9036\304}% U+1EC4
\DeclareTextCompositeCommand{\'}{PU}{I}{\80\315}% U+00CD
\DeclareTextCompositeCommand{\d}{PU}{I}{\9036\312}% U+1ECA
\DeclareTextCompositeCommand{\`}{PU}{I}{\80\314}% U+00CC
\DeclareTextCompositeCommand{\h}{PU}{I}{\9036\310}% U+1EC8
\DeclareTextCompositeCommand{\~}{PU}{I}{\81\050}% U+0128
\DeclareTextCompositeCommand{\'}{PU}{O}{\80\323}% U+00D3
\DeclareTextCompositeCommand{\d}{PU}{O}{\9036\314}% U+1ECC
\DeclareTextCompositeCommand{\`}{PU}{O}{\80\322}% U+00D2
\DeclareTextCompositeCommand{\h}{PU}{O}{\9036\316}% U+1ECE
\DeclareTextCompositeCommand{\~}{PU}{O}{\80\325}% U+00D5
\DeclareTextCompositeCommand{\'}{PU}{\OCIRCUMFLEX}{\9036\320}% U+1ED0
\DeclareTextCompositeCommand{\d}{PU}{\OCIRCUMFLEX}{\9036\330}% U+1ED8
\DeclareTextCompositeCommand{\`}{PU}{\OCIRCUMFLEX}{\9036\322}% U+1ED2
\DeclareTextCompositeCommand{\h}{PU}{\OCIRCUMFLEX}{\9036\324}% U+1ED4
\DeclareTextCompositeCommand{\~}{PU}{\OCIRCUMFLEX}{\9036\326}% U+1ED6
\DeclareTextCompositeCommand{\'}{PU}{\OHORN}{\9036\332}% U+1EDA
\DeclareTextCompositeCommand{\d}{PU}{\OHORN}{\9036\342}% U+1EE2
\DeclareTextCompositeCommand{\`}{PU}{\OHORN}{\9036\334}% U+1EDC
\DeclareTextCompositeCommand{\h}{PU}{\OHORN}{\9036\336}% U+1EDE
\DeclareTextCompositeCommand{\~}{PU}{\OHORN}{\9036\340}% U+1EE0
\DeclareTextCompositeCommand{\'}{PU}{U}{\80\332}% U+00DA
\DeclareTextCompositeCommand{\d}{PU}{U}{\9036\344}% U+1EE4
\DeclareTextCompositeCommand{\`}{PU}{U}{\80\331}% U+00D9
\DeclareTextCompositeCommand{\h}{PU}{U}{\9036\346}% U+1EE6
\DeclareTextCompositeCommand{\~}{PU}{U}{\81\150}% U+0168
\DeclareTextCompositeCommand{\'}{PU}{\UHORN}{\9036\350}% U+1EE8
\DeclareTextCompositeCommand{\d}{PU}{\UHORN}{\9036\360}% U+1EF0
\DeclareTextCompositeCommand{\`}{PU}{\UHORN}{\9036\352}% U+1EEA
\DeclareTextCompositeCommand{\h}{PU}{\UHORN}{\9036\354}% U+1EEC
\DeclareTextCompositeCommand{\~}{PU}{\UHORN}{\9036\356}% U+1EEE
\DeclareTextCompositeCommand{\'}{PU}{Y}{\80\335}% U+00DD
\DeclareTextCompositeCommand{\d}{PU}{Y}{\9036\364}% U+1EF4
\DeclareTextCompositeCommand{\`}{PU}{Y}{\9036\362}% U+1EF2
\DeclareTextCompositeCommand{\h}{PU}{Y}{\9036\366}% U+1EF6
\DeclareTextCompositeCommand{\~}{PU}{Y}{\9036\370}% U+1EF8
\endinput
%%
%% End of file `puvnenc.def'.
