%%
%% This is file `latin10.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% inputenc.dtx  (with options: `latin10')
%% 
%% This is a generated file.
%% 
%% The source is maintained by the LaTeX Project team and bug
%% reports for it can be opened at https://latex-project.org/bugs.html
%% (but please observe conditions on bug reports sent to that address!)
%% 
%% 
%% Copyright (C) 1993-2025
%% The LaTeX Project and any individual authors listed elsewhere
%% in this file.
%% 
%% This file was generated from file(s) of the LaTeX base system.
%% --------------------------------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2008 or later.
%% 
%% This file has the LPPL maintenance status "maintained".
%% 
%% This file may only be distributed together with a copy of the LaTeX
%% base system. You may however distribute the LaTeX base system without
%% such generated files.
%% 
%% The list of all files belonging to the LaTeX base distribution is
%% given in the file `manifest.txt'. See also `legal.txt' for additional
%% information.
%% 
%% The list of derived (unpacked) files belonging to the distribution
%% and covered by LPPL is defined by the unpacking scripts (with
%% extension .ins) which are part of the distribution.

 \ProvidesFile{latin10.def}
   [2024/02/08 v1.3d Input encoding file]
\ProvideTextCommandDefault{\textdegree}{\ensuremath{{^\circ}}}
\ProvideTextCommandDefault{\texteuro}
   {\TextSymbolUnavailable\texteuro}
\ProvideTextCommandDefault\textcommabelow[1]
  {\hmode@bgroup\ooalign{\null#1\crcr\hidewidth
     \raise-.31ex\hbox{\check@mathfonts
                       \fontsize\ssf@size\z@
                       \math@fontsfalse\selectfont,}\hidewidth}\egroup}
\ProvideTextCommandDefault\textpm{\ensuremath\pm}
\DeclareInputText{160}{\nobreakspace}
\DeclareInputText{161}{\k A}
\DeclareInputText{162}{\k a}
\DeclareInputText{163}{\L}
\DeclareInputText{164}{\texteuro}
\DeclareInputText{165}{\quotedblbase}
\DeclareInputText{166}{\v S}
\DeclareInputText{167}{\S}
\DeclareInputText{168}{\v s}
\DeclareInputText{169}{\textcopyright}
\DeclareInputText{170}{\textcommabelow S}
\DeclareInputText{171}{\guillemetleft}
\DeclareInputText{172}{\@tabacckludge'Z}
\DeclareInputText{173}{\-}
\DeclareInputText{174}{\@tabacckludge'z}
\DeclareInputText{175}{\.Z}
\DeclareInputText{176}{\textdegree}
\DeclareInputText{177}{\textpm}
\DeclareInputText{178}{\v C}
\DeclareInputText{179}{\l}
\DeclareInputText{180}{\v Z}
\DeclareInputText{181}{\textquotedblright}
\DeclareInputText{182}{\P}
\DeclareInputText{183}{\textperiodcentered}
\DeclareInputText{184}{\v z}
\DeclareInputText{185}{\v c}
\DeclareInputText{186}{\textcommabelow s}
\DeclareInputText{187}{\guillemetright}
\DeclareInputText{188}{\OE}
\DeclareInputText{189}{\oe}
\DeclareInputText{190}{\"Y}
\DeclareInputText{191}{\.z}
\DeclareInputText{192}{\@tabacckludge`A}
\DeclareInputText{193}{\@tabacckludge'A}
\DeclareInputText{194}{\^A}
\DeclareInputText{195}{\u A}
\DeclareInputText{196}{\"A}
\DeclareInputText{197}{\@tabacckludge'C}
\DeclareInputText{198}{\AE}
\DeclareInputText{199}{\c C}
\DeclareInputText{200}{\@tabacckludge`E}
\DeclareInputText{201}{\@tabacckludge'E}
\DeclareInputText{202}{\^E}
\DeclareInputText{203}{\"E}
\DeclareInputText{204}{\@tabacckludge`I}
\DeclareInputText{205}{\@tabacckludge'I}
\DeclareInputText{206}{\^I}
\DeclareInputText{207}{\"I}
\DeclareInputText{208}{\DJ}
\DeclareInputText{209}{\@tabacckludge'N}
\DeclareInputText{210}{\@tabacckludge`O}
\DeclareInputText{211}{\@tabacckludge'O}
\DeclareInputText{212}{\^O}
\DeclareInputText{213}{\H O}
\DeclareInputText{214}{\"O}
\DeclareInputText{215}{\@tabacckludge'S}
\DeclareInputText{216}{\H U}
\DeclareInputText{217}{\@tabacckludge`U}
\DeclareInputText{218}{\@tabacckludge'U}
\DeclareInputText{219}{\^U}
\DeclareInputText{220}{\"U}
\DeclareInputText{221}{\k E}
\DeclareInputText{222}{\textcommabelow T}
\DeclareInputText{223}{\ss}
\DeclareInputText{224}{\@tabacckludge`a}
\DeclareInputText{225}{\@tabacckludge'a}
\DeclareInputText{226}{\^a}
\DeclareInputText{227}{\u a}
\DeclareInputText{228}{\"a}
\DeclareInputText{229}{\@tabacckludge'c}
\DeclareInputText{230}{\ae}
\DeclareInputText{231}{\c c}
\DeclareInputText{232}{\@tabacckludge`e}
\DeclareInputText{233}{\@tabacckludge'e}
\DeclareInputText{234}{\^e}
\DeclareInputText{235}{\"e}
\DeclareInputText{236}{\@tabacckludge`\i}
\DeclareInputText{237}{\@tabacckludge'\i}
\DeclareInputText{238}{\^\i}
\DeclareInputText{239}{\"\i}
\DeclareInputText{240}{\dj}
\DeclareInputText{241}{\@tabacckludge'n}
\DeclareInputText{242}{\@tabacckludge`o}
\DeclareInputText{243}{\@tabacckludge'o}
\DeclareInputText{244}{\^o}
\DeclareInputText{245}{\H o}
\DeclareInputText{246}{\"o}
\DeclareInputText{247}{\@tabacckludge's}
\DeclareInputText{248}{\H u}
\DeclareInputText{249}{\@tabacckludge`u}
\DeclareInputText{250}{\@tabacckludge'u}
\DeclareInputText{251}{\^u}
\DeclareInputText{252}{\"u}
\DeclareInputText{253}{\k e}
\DeclareInputText{254}{\textcommabelow t}
\DeclareInputText{255}{\"y}
\endinput
%%
%% End of file `latin10.def'.
