%%
%% This is file `puenc-extra.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref.dtx  (with options: `puextra')
%% 
%% Copyright
%% 1995-2001 Sebastian Rahtz, with portions written by David Carlisle and Heiko Oberdiek
%% 2001-2015 Heiko Oberdiek
%% 2016-2019 Oberdiek Package Support Group
%% 2019-2026 LaTeX Project
%%      https://github.com/latex3/hyperref/issues
%% 
%% This file is part of the `Hyperref Bundle'.
%% -------------------------------------------
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status `maintained'.
%% 
%% The Current Maintainer of this work is the LaTeX Project.
%% 
%% The list of all files belonging to the `Hyperref Bundle' is
%% given in the file `manifest.txt'.
%% 
%% File: hyperref.dtx
\ProvidesFile{puenc-extra.def}
  [2026-01-29 v7.01p %
  Hyperref: PDF Unicode extra definition (HO)]
\DeclareTextCommand{\G}{PU}[1]{#1\83\017}% U+030F
\DeclareTextCompositeCommand{\G}{PU}{\@empty}{\textdoublegrave}%
\DeclareTextCompositeCommand{\G}{PU}{\ }{\textdoublegrave}%
\DeclareTextCompositeCommand{\G}{PU}{A}{\82\000}% U+0200
\DeclareTextCompositeCommand{\G}{PU}{a}{\82\001}% U+0201
\DeclareTextCompositeCommand{\G}{PU}{E}{\82\004}% U+0204
\DeclareTextCompositeCommand{\G}{PU}{e}{\82\005}% U+0205
\DeclareTextCompositeCommand{\G}{PU}{I}{\82\010}% U+0208
\DeclareTextCompositeCommand{\G}{PU}{\i}{\82\011}% U+0209
\DeclareTextCompositeCommand{\G}{PU}{i}{\82\011}% U+0209
\DeclareTextCompositeCommand{\G}{PU}{O}{\82\014}% U+020C
\DeclareTextCompositeCommand{\G}{PU}{o}{\82\015}% U+020D
\DeclareTextCompositeCommand{\G}{PU}{R}{\82\020}% U+0210
\DeclareTextCompositeCommand{\G}{PU}{r}{\82\021}% U+0211
\DeclareTextCompositeCommand{\G}{PU}{U}{\82\024}% U+0214
\DeclareTextCompositeCommand{\G}{PU}{u}{\82\025}% U+0215
\endinput
%%
%% End of file `puenc-extra.def'.
