%%
%% This is file `psdextra.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% hyperref.dtx  (with options: `psdextra')
%% 
%% Copyright
%% 1995-2001 Sebastian Rahtz, with portions written by David Carlisle and Heiko Oberdiek
%% 2001-2015 Heiko Oberdiek
%% 2016-2019 Oberdiek Package Support Group
%% 2019-2026 LaTeX Project
%%      https://github.com/latex3/hyperref/issues
%% 
%% This file is part of the `Hyperref Bundle'.
%% -------------------------------------------
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status `maintained'.
%% 
%% The Current Maintainer of this work is the LaTeX Project.
%% 
%% The list of all files belonging to the `Hyperref Bundle' is
%% given in the file `manifest.txt'.
%% 
%% File: hyperref.dtx
\ProvidesFile{psdextra.def}
  [2026-01-29 v7.01p %
  Hyperref: Additions to PDF string support]
\Hy@VersionCheck{psdextra.def}
\DeclareTextCommand{\textGamma}{PU}{\83\223}%* U+0393
\DeclareTextCommand{\textDelta}{PU}{\83\224}%* U+0394
\DeclareTextCommand{\textTheta}{PU}{\83\230}%* U+0398
\DeclareTextCommand{\textLambda}{PU}{\83\233}%* U+039B
\DeclareTextCommand{\textXi}{PU}{\83\236}%* U+039E
\DeclareTextCommand{\textPi}{PU}{\83\240}%* U+03A0
\DeclareTextCommand{\textSigma}{PU}{\83\243}%* U+03A3
\DeclareTextCommand{\textUpsilon}{PU}{\83\245}%* U+03A5
\DeclareTextCommand{\textPhi}{PU}{\83\246}%* U+03A6
\DeclareTextCommand{\textChi}{PU}{\83\247}% U+03A7
\DeclareTextCommand{\textPsi}{PU}{\83\250}%* U+03A8
\DeclareTextCommand{\textOmega}{PU}{\83\251}%* U+03A9
\DeclareTextCommand{\textalpha}{PU}{\83\261}%* U+03B1
\DeclareTextCommand{\textbeta}{PU}{\83\262}%* U+03B2
\DeclareTextCommand{\textgamma}{PU}{\83\263}%* U+03B3
\DeclareTextCommand{\textdelta}{PU}{\83\264}%* U+03B4
\DeclareTextCommand{\textepsilon}{PU}{\83\265}%* U+03B5
\DeclareTextCommand{\textzeta}{PU}{\83\266}%* U+03B6
\DeclareTextCommand{\texteta}{PU}{\83\267}%* U+03B7
\DeclareTextCommand{\texttheta}{PU}{\83\270}%* U+03B8
\DeclareTextCommand{\textiota}{PU}{\83\271}%* U+03B9
\DeclareTextCommand{\textkappa}{PU}{\83\272}%* U+03BA
\DeclareTextCommand{\textlambda}{PU}{\83\273}%* U+03BB
\DeclareTextCommand{\textmugreek}{PU}{\83\274}%* U+03BC
\DeclareTextCommand{\textnu}{PU}{\83\275}%* U+03BD
\DeclareTextCommand{\textxi}{PU}{\83\276}%* U+03BE
\DeclareTextCommand{\textpi}{PU}{\83\300}%* U+03C0
\DeclareTextCommand{\textrho}{PU}{\83\301}%* U+03C1
\DeclareTextCommand{\textvarsigma}{PU}{\83\302}%* U+03C2
\DeclareTextCommand{\textsigma}{PU}{\83\303}%* U+03C3
\DeclareTextCommand{\texttau}{PU}{\83\304}%* U+03C4
\DeclareTextCommand{\textupsilon}{PU}{\83\305}%* U+03C5
\DeclareTextCommand{\textphi}{PU}{\83\306}%* U+03C6
\DeclareTextCommand{\textchi}{PU}{\83\307}%* U+03C7
\DeclareTextCommand{\textpsi}{PU}{\83\310}%* U+03C8
\DeclareTextCommand{\textomega}{PU}{\83\311}%* U+03C9
\newcommand*{\psdmapshortnames}{%
  \let\MVPlus\textMVPlus
  \let\MVComma\textMVComma
  \let\MVMinus\textMVMinus
  \let\MVPeriod\textMVPeriod
  \let\MVDivision\textMVDivision
  \let\MVZero\textMVZero
  \let\MVOne\textMVOne
  \let\MVTwo\textMVTwo
  \let\MVThree\textMVThree
  \let\MVFour\textMVFour
  \let\MVFive\textMVFive
  \let\MVSix\textMVSix
  \let\MVSeven\textMVSeven
  \let\MVEight\textMVEight
  \let\MVNine\textMVNine
  \let\MVAt\textMVAt
  \let\copyright\textcopyright
  \let\twosuperior\texttwosuperior
  \let\threesuperior\textthreesuperior
  \let\onesuperior\textonesuperior
  \let\Thorn\textThorn
  \let\thorn\textthorn
  \let\hbar\texthbar
  \let\hausaB\texthausaB
  \let\hausaD\texthausaD
  \let\hausaK\texthausaK
  \let\barl\textbarl
  \let\inve\textinve
  \let\slashc\textslashc
  \let\scripta\textscripta
  \let\openo\textopeno
  \let\rtaild\textrtaild
  \let\reve\textreve
  \let\schwa\textschwa
  \let\niepsilon\textniepsilon
  \let\revepsilon\textrevepsilon
  \let\rhookrevepsilon\textrhookrevepsilon
  \let\scriptg\textscriptg
  \let\scg\textscg
  \let\ipagamma\textipagamma
  \let\babygamma\textbabygamma
  \let\bari\textbari
  \let\niiota\textniiota
  \let\sci\textsci
  \let\scn\textscn
  \let\niphi\textniphi
  \let\longlegr\textlonglegr
  \let\scr\textscr
  \let\invscr\textinvscr
  \let\esh\textesh
  \let\baru\textbaru
  \let\niupsilon\textniupsilon
  \let\scriptv\textscriptv
  \let\turnv\textturnv
  \let\turnw\textturnw
  \let\turny\textturny
  \let\scy\textscy
  \let\yogh\textyogh
  \let\glotstop\textglotstop
  \let\revglotstop\textrevglotstop
  \let\invglotstop\textinvglotstop
  \let\Gamma\textGamma
  \let\Delta\textDelta
  \let\Theta\textTheta
  \let\Lambda\textLambda
  \let\Xi\textXi
  \let\Pi\textPi
  \let\Sigma\textSigma
  \let\Upsilon\textUpsilon
  \let\Phi\textPhi
  \let\Psi\textPsi
  \let\Omega\textOmega
  \let\alpha\textalpha
  \let\beta\textbeta
  \let\gamma\textgamma
  \let\delta\textdelta
  \let\epsilon\textepsilon
  \let\zeta\textzeta
  \let\eta\texteta
  \let\theta\texttheta
  \let\iota\textiota
  \let\kappa\textkappa
  \let\lambda\textlambda
  \let\mu\textmu
  \let\mugreek\textmugreek
  \let\nu\textnu
  \let\xi\textxi
  \let\pi\textpi
  \let\rho\textrho
  \let\varsigma\textvarsigma
  \let\sigma\textsigma
  \let\tau\texttau
  \let\upsilon\textupsilon
  \let\phi\textphi
  \let\chi\textchi
  \let\psi\textpsi
  \let\omega\textomega
  \let\scd\textscd
  \let\scu\textscu
  \let\iinferior\textiinferior
  \let\rinferior\textrinferior
  \let\uinferior\textuinferior
  \let\vinferior\textvinferior
  \let\betainferior\textbetainferior
  \let\gammainferior\textgammainferior
  \let\rhoinferior\textrhoinferior
  \let\phiinferior\textphiinferior
  \let\chiinferior\textchiinferior
  \let\barsci\textbarsci
  \let\barp\textbarp
  \let\barscu\textbarscu
  \let\htrtaild\texthtrtaild
  \let\dagger\textdagger
  \let\bullet\textbullet
  \let\hdotfor\texthdotfor
  \let\prime\textprime
  \let\second\textsecond
  \let\third\textthird
  \let\backprime\textbackprime
  \let\lefttherefore\textlefttherefore
  \let\fourth\textfourth
  \let\diamonddots\textdiamonddots
  \let\zerosuperior\textzerosuperior
  \let\isuperior\textisuperior
  \let\foursuperior\textfoursuperior
  \let\fivesuperior\textfivesuperior
  \let\sixsuperior\textsixsuperior
  \let\sevensuperior\textsevensuperior
  \let\eightsuperior\texteightsuperior
  \let\ninesuperior\textninesuperior
  \let\plussuperior\textplussuperior
  \let\minussuperior\textminussuperior
  \let\equalsuperior\textequalsuperior
  \let\parenleftsuperior\textparenleftsuperior
  \let\parenrightsuperior\textparenrightsuperior
  \let\nsuperior\textnsuperior
  \let\zeroinferior\textzeroinferior
  \let\oneinferior\textoneinferior
  \let\twoinferior\texttwoinferior
  \let\threeinferior\textthreeinferior
  \let\fourinferior\textfourinferior
  \let\fiveinferior\textfiveinferior
  \let\sixinferior\textsixinferior
  \let\seveninferior\textseveninferior
  \let\eightinferior\texteightinferior
  \let\nineinferior\textnineinferior
  \let\plusinferior\textplusinferior
  \let\minusinferior\textminusinferior
  \let\equalsinferior\textequalsinferior
  \let\parenleftinferior\textparenleftinferior
  \let\parenrightinferior\textparenrightinferior
  \let\ainferior\textainferior
  \let\einferior\texteinferior
  \let\oinferior\textoinferior
  \let\xinferior\textxinferior
  \let\schwainferior\textschwainferior
  \let\hinferior\texthinferior
  \let\kinferior\textkinferior
  \let\linferior\textlinferior
  \let\minferior\textminferior
  \let\ninferior\textninferior
  \let\pinferior\textpinferior
  \let\sinferior\textsinferior
  \let\tinferior\texttinferior
  \let\Deleatur\textDeleatur
  \let\hslash\texthslash
  \let\Im\textIm
  \let\ell\textell
  \let\wp\textwp
  \let\Re\textRe
  \let\mho\textmho
  \let\riota\textriota
  \let\Finv\textFinv
  \let\aleph\textaleph
  \let\beth\textbeth
  \let\gimel\textgimel
  \let\daleth\textdaleth
  \let\fax\textfax
  \let\Game\textGame
  \let\leftarrow\textleftarrow
  \let\uparrow\textuparrow
  \let\rightarrow\textrightarrow
  \let\downarrow\textdownarrow
  \let\leftrightarrow\textleftrightarrow
  \let\updownarrow\textupdownarrow
  \let\nwarrow\textnwarrow
  \let\nearrow\textnearrow
  \let\searrow\textsearrow
  \let\swarrow\textswarrow
  \let\nleftarrow\textnleftarrow
  \let\nrightarrow\textnrightarrow
  \let\twoheadleftarrow\texttwoheadleftarrow
  \let\ntwoheadleftarrow\textntwoheadleftarrow
  \let\twoheaduparrow\texttwoheaduparrow
  \let\twoheadrightarrow\texttwoheadrightarrow
  \let\ntwoheadrightarrow\textntwoheadrightarrow
  \let\twoheaddownarrow\texttwoheaddownarrow
  \let\leftarrowtail\textleftarrowtail
  \let\rightarrowtail\textrightarrowtail
  \let\mapsto\textmapsto
  \let\hookleftarrow\texthookleftarrow
  \let\hookrightarrow\texthookrightarrow
  \let\looparrowleft\textlooparrowleft
  \let\looparrowright\textlooparrowright
  \let\nleftrightarrow\textnleftrightarrow
  \let\lightning\textlightning
  \let\dlsh\textdlsh
  \let\curvearrowleft\textcurvearrowleft
  \let\curvearrowright\textcurvearrowright
  \let\leftharpoonup\textleftharpoonup
  \let\leftharpoondown\textleftharpoondown
  \let\upharpoonright\textupharpoonright
  \let\upharpoonleft\textupharpoonleft
  \let\rightharpoonup\textrightharpoonup
  \let\rightharpoondown\textrightharpoondown
  \let\downharpoonright\textdownharpoonright
  \let\downharpoonleft\textdownharpoonleft
  \let\rightleftarrows\textrightleftarrows
  \let\updownarrows\textupdownarrows
  \let\leftrightarrows\textleftrightarrows
  \let\leftleftarrows\textleftleftarrows
  \let\upuparrows\textupuparrows
  \let\rightrightarrows\textrightrightarrows
  \let\downdownarrows\textdowndownarrows
  \let\leftrightharpoons\textleftrightharpoons
  \let\rightleftharpoons\textrightleftharpoons
  \let\nLeftarrow\textnLeftarrow
  \let\nLeftrightarrow\textnLeftrightarrow
  \let\nRightarrow\textnRightarrow
  \let\Leftarrow\textLeftarrow
  \let\Uparrow\textUparrow
  \let\Rightarrow\textRightarrow
  \let\Downarrow\textDownarrow
  \let\Leftrightarrow\textLeftrightarrow
  \let\Updownarrow\textUpdownarrow
  \let\Nwarrow\textNwarrow
  \let\Nearrow\textNearrow
  \let\Searrow\textSearrow
  \let\Swarrow\textSwarrow
  \let\Lleftarrow\textLleftarrow
  \let\Rrightarrow\textRrightarrow
  \let\leftsquigarrow\textleftsquigarrow
  \let\rightsquigarrow\textrightsquigarrow
  \let\dashleftarrow\textdashleftarrow
  \let\dasheduparrow\textdasheduparrow
  \let\dashrightarrow\textdashrightarrow
  \let\dasheddownarrow\textdasheddownarrow
  \let\pointer\textpointer
  \let\downuparrows\textdownuparrows
  \let\leftarrowtriangle\textleftarrowtriangle
  \let\rightarrowtriangle\textrightarrowtriangle
  \let\leftrightarrowtriangle\textleftrightarrowtriangle
  \let\forall\textforall
  \let\complement\textcomplement
  \let\partial\textpartial
  \let\exists\textexists
  \let\nexists\textnexists
  \let\emptyset\textemptyset
  \let\triangle\texttriangle
  \let\nabla\textnabla
  \let\in\textinsymbol
  \let\notin\textnotin
  \let\smallin\textsmallin
  \let\ni\textni
  \let\notowner\textnotowner
  \let\smallowns\textsmallowns
  \let\prod\textprod
  \let\amalg\textamalg
  \let\sum\textsum
  \let\mp\textmp
  \let\dotplus\textdotplus
  \let\Divides\textDivides
  \let\DividesNot\textDividesNot
  \let\setminus\textsetminus
  \let\ast\textast
  \let\circ\textcirc
  \let\surd\textsurd
  \let\propto\textpropto
  \let\infty\textinfty
  \let\angle\textangle
  \let\measuredangle\textmeasuredangle
  \let\sphericalangle\textsphericalangle
  \let\mid\textmid
  \let\nmid\textnmid
  \let\parallel\textparallel
  \let\nparallel\textnparallel
  \let\wedge\textwedge
  \let\owedge\textowedge
  \let\vee\textvee
  \let\ovee\textovee
  \let\cap\textcap
  \let\cup\textcup
  \let\int\textint
  \let\iint\textiint
  \let\iiint\textiiint
  \let\oint\textoint
  \let\oiint\textoiint
  \let\ointclockwise\textointclockwise
  \let\ointctrclockwise\textointctrclockwise
  \let\therefore\texttherefore
  \let\because\textbecause
  \let\vdotdot\textvdotdot
  \let\squaredots\textsquaredots
  \let\dotminus\textdotminus
  \let\eqcolon\texteqcolon
  \let\sim\textsim
  \let\backsim\textbacksim
  \let\nbacksim\textnbacksim
  \let\wr\textwr
  \let\nsim\textnsim
  \let\eqsim\texteqsim
  \let\neqsim\textneqsim
  \let\simeq\textsimeq
  \let\nsimeq\textnsimeq
  \let\cong\textcong
  \let\ncong\textncong
  \let\approx\textapprox
  \let\napprox\textnapprox
  \let\approxeq\textapproxeq
  \let\napproxeq\textnapproxeq
  \let\triplesim\texttriplesim
  \let\ntriplesim\textntriplesim
  \let\backcong\textbackcong
  \let\nbackcong\textnbackcong
  \let\asymp\textasymp
  \let\nasymp\textnasymp
  \let\Bumpeq\textBumpeq
  \let\nBumpeq\textnBumpeq
  \let\bumpeq\textbumpeq
  \let\nbumpeq\textnbumpeq
  \let\doteq\textdoteq
  \let\ndoteq\textndoteq
  \let\doteqdot\textdoteqdot
  \let\nDoteq\textnDoteq
  \let\fallingdoteq\textfallingdoteq
  \let\nfallingdoteq\textnfallingdoteq
  \let\risingdoteq\textrisingdoteq
  \let\nrisingdoteq\textnrisingdoteq
  \let\colonequals\textcolonequals
  \let\equalscolon\textequalscolon
  \let\eqcirc\texteqcirc
  \let\neqcirc\textneqcirc
  \let\circeq\textcirceq
  \let\ncirceq\textncirceq
  \let\hateq\texthateq
  \let\nhateq\textnhateq
  \let\triangleeq\texttriangleeq
  \let\neq\textneq
  \let\ne\textne
  \let\equiv\textequiv
  \let\nequiv\textnequiv
  \let\leq\textleq
  \let\le\textle
  \let\geq\textgeq
  \let\ge\textge
  \let\leqq\textleqq
  \let\nleqq\textnleqq
  \let\geqq\textgeqq
  \let\ngeqq\textngeqq
  \let\lneqq\textlneqq
  \let\gneqq\textgneqq
  \let\ll\textll
  \let\nll\textnll
  \let\gg\textgg
  \let\ngg\textngg
  \let\between\textbetween
  \let\nless\textnless
  \let\ngtr\textngtr
  \let\nleq\textnleq
  \let\ngeq\textngeq
  \let\lesssim\textlesssim
  \let\gtrsim\textgtrsim
  \let\nlesssim\textnlesssim
  \let\ngtrsim\textngtrsim
  \let\lessgtr\textlessgtr
  \let\gtrless\textgtrless
  \let\ngtrless\textngtrless
  \let\nlessgtr\textnlessgtr
  \let\prec\textprec
  \let\succ\textsucc
  \let\preccurlyeq\textpreccurlyeq
  \let\succcurlyeq\textsucccurlyeq
  \let\precsim\textprecsim
  \let\nprecsim\textnprecsim
  \let\succsim\textsuccsim
  \let\nsuccsim\textnsuccsim
  \let\nprec\textnprec
  \let\nsucc\textnsucc
  \let\subset\textsubset
  \let\supset\textsupset
  \let\nsubset\textnsubset
  \let\nsupset\textnsupset
  \let\subseteq\textsubseteq
  \let\supseteq\textsupseteq
  \let\nsubseteq\textnsubseteq
  \let\nsupseteq\textnsupseteq
  \let\subsetneq\textsubsetneq
  \let\supsetneq\textsupsetneq
  \let\cupdot\textcupdot
  \let\cupplus\textcupplus
  \let\sqsubset\textsqsubset
  \let\nsqsubset\textnsqsubset
  \let\sqsupset\textsqsupset
  \let\nsqsupset\textnsqsupset
  \let\sqsubseteq\textsqsubseteq
  \let\nsqsubseteq\textnsqsubseteq
  \let\sqsupseteq\textsqsupseteq
  \let\nsqsupseteq\textnsqsupseteq
  \let\sqcap\textsqcap
  \let\sqcup\textsqcup
  \let\oplus\textoplus
  \let\ominus\textominus
  \let\otimes\textotimes
  \let\oslash\textoslash
  \let\odot\textodot
  \let\circledcirc\textcircledcirc
  \let\circledast\textcircledast
  \let\circleddash\textcircleddash
  \let\boxplus\textboxplus
  \let\boxminus\textboxminus
  \let\boxtimes\textboxtimes
  \let\boxdot\textboxdot
  \let\vdash\textvdash
  \let\dashv\textdashv
  \let\ndashv\textndashv
  \let\top\texttop
  \let\ndownvdash\textndownvdash
  \let\bot\textbot
  \let\nupvdash\textnupvdash
  \let\vDash\textvDash
  \let\Vdash\textVdash
  \let\Vvdash\textVvdash
  \let\nVvash\textnVvash
  \let\VDash\textVDash
  \let\nvdash\textnvdash
  \let\nvDash\textnvDash
  \let\nVdash\textnVdash
  \let\nVDash\textnVDash
  \let\lhd\textlhd
  \let\rhd\textrhd
  \let\unlhd\textunlhd
  \let\unrhd\textunrhd
  \let\multimapdotbothA\textmultimapdotbothA
  \let\multimapdotbothB\textmultimapdotbothB
  \let\multimap\textmultimap
  \let\veebar\textveebar
  \let\barwedge\textbarwedge
  \let\star\textstar
  \let\divideontimes\textdivideontimes
  \let\bowtie\textbowtie
  \let\ltimes\textltimes
  \let\rtimes\textrtimes
  \let\leftthreetimes\textleftthreetimes
  \let\rightthreetimes\textrightthreetimes
  \let\backsimeq\textbacksimeq
  \let\nbacksimeq\textnbacksimeq
  \let\curlyvee\textcurlyvee
  \let\curlywedge\textcurlywedge
  \let\Subset\textSubset
  \let\nSubset\textnSubset
  \let\Supset\textSupset
  \let\nSupset\textnSupset
  \let\Cap\textCap
  \let\Cup\textCup
  \let\pitchfork\textpitchfork
  \let\lessdot\textlessdot
  \let\gtrdot\textgtrdot
  \let\lll\textlll
  \let\ggg\textggg
  \let\lesseqgtr\textlesseqgtr
  \let\gtreqless\textgtreqless
  \let\curlyeqprec\textcurlyeqprec
  \let\ncurlyeqprec\textncurlyeqprec
  \let\curlyeqsucc\textcurlyeqsucc
  \let\ncurlyeqsucc\textncurlyeqsucc
  \let\npreccurlyeq\textnpreccurlyeq
  \let\nsucccurlyeq\textnsucccurlyeq
  \let\nqsubseteq\textnqsubseteq
  \let\nqsupseteq\textnqsupseteq
  \let\sqsubsetneq\textsqsubsetneq
  \let\sqsupsetneq\textsqsupsetneq
  \let\lnsim\textlnsim
  \let\gnsim\textgnsim
  \let\precnsim\textprecnsim
  \let\succnsim\textsuccnsim
  \let\ntriangleleft\textntriangleleft
  \let\ntriangleright\textntriangleright
  \let\ntrianglelefteq\textntrianglelefteq
  \let\ntrianglerighteq\textntrianglerighteq
  \let\vdots\textvdots
  \let\cdots\textcdots
  \let\udots\textudots
  \let\ddots\textddots
  \let\barin\textbarin
  \let\diameter\textdiameter
  \let\backneg\textbackneg
  \let\wasylozenge\textwasylozenge
  \let\invbackneg\textinvbackneg
  \let\clock\textclock
  \let\ulcorner\textulcorner
  \let\urcorner\texturcorner
  \let\llcorner\textllcorner
  \let\lrcorner\textlrcorner
  \let\frown\textfrown
  \let\smile\textsmile
  \let\Keyboard\textKeyboard
  \let\langle\textlangle
  \let\rangle\textrangle
  \let\APLinv\textAPLinv
  \let\Tumbler\textTumbler
  \let\notslash\textnotslash
  \let\notbackslash\textnotbackslash
  \let\boxbackslash\textboxbackslash
  \let\APLleftarrowbox\textAPLleftarrowbox
  \let\APLrightarrowbox\textAPLrightarrowbox
  \let\APLuparrowbox\textAPLuparrowbox
  \let\APLdownarrowbox\textAPLdownarrowbox
  \let\APLinput\textAPLinput
  \let\Request\textRequest
  \let\Beam\textBeam
  \let\hexagon\texthexagon
  \let\APLbox\textAPLbox
  \let\ForwardToIndex\textForwardToIndex
  \let\RewindToIndex\textRewindToIndex
  \let\bbslash\textbbslash
  \let\CircledA\textCircledA
  \let\CleaningF\textCleaningF
  \let\CleaningFF\textCleaningFF
  \let\CleaningP\textCleaningP
  \let\CleaningPP\textCleaningPP
  \let\CuttingLine\textCuttingLine
  \let\UParrow\textUParrow
  \let\bigtriangleup\textbigtriangleup
  \let\Forward\textForward
  \let\triangleright\texttriangleright
  \let\RHD\textRHD
  \let\DOWNarrow\textDOWNarrow
  \let\bigtriangledown\textbigtriangledown
  \let\Rewind\textRewind
  \let\triangleleft\texttriangleleft
  \let\LHD\textLHD
  \let\diamond\textdiamond
  \let\lozenge\textlozenge
  \let\LEFTCIRCLE\textLEFTCIRCLE
  \let\RIGHTCIRCLE\textRIGHTCIRCLE
  \let\openbullet\textopenbullet
  \let\boxbar\textboxbar
  \let\bigcircle\textbigcircle
  \let\Cloud\textCloud
  \let\FiveStar\textFiveStar
  \let\FiveStarOpen\textFiveStarOpen
  \let\Phone\textPhone
  \let\boxempty\textboxempty
  \let\Checkedbox\textCheckedbox
  \let\Crossedbox\textCrossedbox
  \let\Coffeecup\textCoffeecup
  \let\HandCuffLeft\textHandCuffLeft
  \let\HandCuffRight\textHandCuffRight
  \let\HandLeft\textHandLeft
  \let\HandRight\textHandRight
  \let\Radioactivity\textRadioactivity
  \let\Biohazard\textBiohazard
  \let\Ankh\textAnkh
  \let\YinYang\textYinYang
  \let\frownie\textfrownie
  \let\smiley\textsmiley
  \let\blacksmiley\textblacksmiley
  \let\sun\textsun
  \let\leftmoon\textleftmoon
  \let\rightmoon\textrightmoon
  \let\mercury\textmercury
  \let\earth\textearth
  \let\male\textmale
  \let\jupiter\textjupiter
  \let\saturn\textsaturn
  \let\uranus\texturanus
  \let\neptune\textneptune
  \let\pluto\textpluto
  \let\aries\textaries
  \let\taurus\texttaurus
  \let\gemini\textgemini
  \let\cancer\textcancer
  \let\leo\textleo
  \let\virgo\textvirgo
  \let\libra\textlibra
  \let\scorpio\textscorpio
  \let\sagittarius\textsagittarius
  \let\capricornus\textcapricornus
  \let\aquarius\textaquarius
  \let\pisces\textpisces
  \let\quarternote\textquarternote
  \let\twonotes\texttwonotes
  \let\sixteenthnote\textsixteenthnote
  \let\flat\textflat
  \let\natural\textnatural
  \let\sharp\textsharp
  \let\recycle\textrecycle
  \let\Wheelchair\textWheelchair
  \let\Flag\textFlag
  \let\MineSign\textMineSign
  \let\dsmilitary\textdsmilitary
  \let\dsmedical\textdsmedical
  \let\dsjuridical\textdsjuridical
  \let\dschemical\textdschemical
  \let\dsbiological\textdsbiological
  \let\dscommercial\textdscommercial
  \let\manstar\textmanstar
  \let\danger\textdanger
  \let\FemaleFemale\textFemaleFemale
  \let\MaleMale\textMaleMale
  \let\FemaleMale\textFemaleMale
  \let\Hermaphrodite\textHermaphrodite
  \let\Neutral\textNeutral
  \let\hexstar\texthexstar
  \let\SunCload\textSunCload
  \let\Rain\textRain
  \let\noway\textnoway
  \let\Mountain\textMountain
  \let\Tent\textTent
  \let\ScissorRight\textScissorRight
  \let\ScissorRightBrokenTop\textScissorRightBrokenTop
  \let\ScissorHollowRight\textScissorHollowRight
  \let\PhoneHandset\textPhoneHandset
  \let\Tape\textTape
  \let\Plane\textPlane
  \let\Envelope\textEnvelope
  \let\Peace\textPeace
  \let\WritingHand\textWritingHand
  \let\PencilRightDown\textPencilRightDown
  \let\PencilRight\textPencilRight
  \let\PencilRightUp\textPencilRightUp
  \let\NibRight\textNibRight
  \let\NibSolidRight\textNibSolidRight
  \let\Checkmark\textCheckmark
  \let\CheckmarkBold\textCheckmarkBold
  \let\XSolid\textXSolid
  \let\XSolidBold\textXSolidBold
  \let\XSolidBrush\textXSolidBrush
  \let\PlusOutline\textPlusOutline
  \let\Plus\textPlus
  \let\PlusThinCenterOpen\textPlusThinCenterOpen
  \let\PlusCenterOpen\textPlusCenterOpen
  \let\Cross\textCross
  \let\CrossOpenShadow\textCrossOpenShadow
  \let\CrossOutline\textCrossOutline
  \let\CrossMaltese\textCrossMaltese
  \let\DavidStar\textDavidStar
  \let\FourAsterisk\textFourAsterisk
  \let\JackStar\textJackStar
  \let\JackStarBold\textJackStarBold
  \let\ClowerTips\textClowerTips
  \let\FourStar\textFourStar
  \let\FourStarOpen\textFourStarOpen
  \let\FiveStarOpenCircled\textFiveStarOpenCircled
  \let\FiveStarCenterOpen\textFiveStarCenterOpen
  \let\FiveStarOpenDotted\textFiveStarOpenDotted
  \let\FiveStarOutline\textFiveStarOutline
  \let\FiveStarOutlineHeavy\textFiveStarOutlineHeavy
  \let\FiveStarConvex\textFiveStarConvex
  \let\FiveStarShadow\textFiveStarShadow
  \let\AsteriskBold\textAsteriskBold
  \let\AsteriskCenterOpen\textAsteriskCenterOpen
  \let\EightStarTaper\textEightStarTaper
  \let\EightStarConvex\textEightStarConvex
  \let\SixStar\textSixStar
  \let\EightStar\textEightStar
  \let\EightStarBold\textEightStarBold
  \let\TwelveStar\textTwelveStar
  \let\SixteenStarLight\textSixteenStarLight
  \let\SixFlowerPetalRemoved\textSixFlowerPetalRemoved
  \let\SixFlowerOpenCenter\textSixFlowerOpenCenter
  \let\Asterisk\textAsterisk
  \let\SixFlowerAlternate\textSixFlowerAlternate
  \let\FiveFlowerPetal\textFiveFlowerPetal
  \let\FiveFlowerOpen\textFiveFlowerOpen
  \let\EightFlowerPetal\textEightFlowerPetal
  \let\SunshineOpenCircled\textSunshineOpenCircled
  \let\SixFlowerAltPetal\textSixFlowerAltPetal
  \let\SnowflakeChevron\textSnowflakeChevron
  \let\Snowflake\textSnowflake
  \let\SnowflakeChevronBold\textSnowflakeChevronBold
  \let\Sparkle\textSparkle
  \let\SparkleBold\textSparkleBold
  \let\AsteriskRoundedEnds\textAsteriskRoundedEnds
  \let\EightFlowerPetalRemoved\textEightFlowerPetalRemoved
  \let\EightAsterisk\textEightAsterisk
  \let\CircleShadow\textCircleShadow
  \let\SquareShadowBottomRight\textSquareShadowBottomRight
  \let\SquareTopRight\textSquareTopRight
  \let\SquareCastShadowBottomRight\textSquareCastShadowBottomRight
  \let\SquareCastShadowTopRight\textSquareCastShadowTopRight
  \let\DiamondSolid\textDiamondSolid
  \let\RectangleThin\textRectangleThin
  \let\Rectangle\textRectangle
  \let\RectangleBold\textRectangleBold
  \let\perp\textperp
  \let\notperp\textnotperp
  \let\veedot\textveedot
  \let\wedgedot\textwedgedot
  \let\leftspoon\textleftspoon
  \let\lbrackdbl\textlbrackdbl
  \let\rbrackdbl\textrbrackdbl
  \let\circlearrowleft\textcirclearrowleft
  \let\circlearrowright\textcirclearrowright
  \let\longleftarrow\textlongleftarrow
  \let\longrightarrow\textlongrightarrow
  \let\longleftrightarrow\textlongleftrightarrow
  \let\Longleftarrow\textLongleftarrow
  \let\Longrightarrow\textLongrightarrow
  \let\Longleftrightarrow\textLongleftrightarrow
  \let\longmapsto\textlongmapsto
  \let\Longmapsfrom\textLongmapsfrom
  \let\Longmapsto\textLongmapsto
  \let\nwsearrow\textnwsearrow
  \let\neswarrow\textneswarrow
  \let\lhooknwarrow\textlhooknwarrow
  \let\rhooknearrow\textrhooknearrow
  \let\lhooksearrow\textlhooksearrow
  \let\rhookswarrow\textrhookswarrow
  \let\leadsto\textleadsto
  \let\rcurvearrowne\textrcurvearrowne
  \let\lcurvearrowse\textlcurvearrowse
  \let\lcurvearrowsw\textlcurvearrowsw
  \let\rcurvearrowse\textrcurvearrowse
  \let\lcurvearrowdown\textlcurvearrowdown
  \let\rcurvearrowdown\textrcurvearrowdown
  \let\rcurvearrowleft\textrcurvearrowleft
  \let\rcurvearrowright\textrcurvearrowright
  \let\leftrightharpoon\textleftrightharpoon
  \let\rightleftharpoon\textrightleftharpoon
  \let\updownharpoonrightleft\textupdownharpoonrightleft
  \let\updownharpoonleftright\textupdownharpoonleftright
  \let\leftleftharpoons\textleftleftharpoons
  \let\upupharpoons\textupupharpoons
  \let\rightrightharpoons\textrightrightharpoons
  \let\downdownharpoons\textdowndownharpoons
  \let\leftbarharpoon\textleftbarharpoon
  \let\barleftharpoon\textbarleftharpoon
  \let\rightbarharpoon\textrightbarharpoon
  \let\barrightharpoon\textbarrightharpoon
  \let\updownharpoons\textupdownharpoons
  \let\downupharpoons\textdownupharpoons
  \let\moo\textmoo
  \let\llparenthesis\textllparenthesis
  \let\rrparenthesis\textrrparenthesis
  \let\invdiameter\textinvdiameter
  \let\obar\textobar
  \let\obslash\textobslash
  \let\obot\textobot
  \let\NoChemicalCleaning\textNoChemicalCleaning
  \let\olessthan\textolessthan
  \let\ogreaterthan\textogreaterthan
  \let\boxslash\textboxslash
  \let\boxbslash\textboxbslash
  \let\boxast\textboxast
  \let\boxcircle\textboxcircle
  \let\boxbox\textboxbox
  \let\Valve\textValve
  \let\multimapboth\textmultimapboth
  \let\shuffle\textshuffle
  \let\uplus\textuplus
  \let\bigdoublewedge\textbigdoublewedge
  \let\bigdoublevee\textbigdoublevee
  \let\Join\textJoin
  \let\fatsemi\textfatsemi
  \let\circplus\textcircplus
  \let\minusdot\textminusdot
  \let\dottimes\textdottimes
  \let\dtimes\textdtimes
  \let\odiv\textodiv
  \let\invneg\textinvneg
  \let\sqdoublecap\textsqdoublecap
  \let\capdot\textcapdot
  \let\sqdoublecup\textsqdoublecup
  \let\doublewedge\textdoublewedge
  \let\doublevee\textdoublevee
  \let\doublebarwedge\textdoublebarwedge
  \let\veedoublebar\textveedoublebar
  \let\eqdot\texteqdot
  \let\neqdot\textneqdot
  \let\coloncolonequals\textcoloncolonequals
  \let\leqslant\textleqslant
  \let\nleqslant\textnleqslant
  \let\geqslant\textgeqslant
  \let\ngeqslant\textngeqslant
  \let\lessapprox\textlessapprox
  \let\nlessapprox\textnlessapprox
  \let\gtrapprox\textgtrapprox
  \let\ngtrapprox\textngtrapprox
  \let\lneq\textlneq
  \let\gneq\textgneq
  \let\lnapprox\textlnapprox
  \let\gnapprox\textgnapprox
  \let\lesseqqgtr\textlesseqqgtr
  \let\gtreqqless\textgtreqqless
  \let\eqslantless\texteqslantless
  \let\eqslantgtr\texteqslantgtr
  \let\leftslice\textleftslice
  \let\rightslice\textrightslice
  \let\preceq\textpreceq
  \let\npreceq\textnpreceq
  \let\succeq\textsucceq
  \let\nsucceq\textnsucceq
  \let\precneq\textprecneq
  \let\succneq\textsuccneq
  \let\preceqq\textpreceqq
  \let\npreceqq\textnpreceqq
  \let\succeqq\textsucceqq
  \let\nsucceqq\textnsucceqq
  \let\precneqq\textprecneqq
  \let\succneqq\textsuccneqq
  \let\precapprox\textprecapprox
  \let\nprecapprox\textnprecapprox
  \let\succapprox\textsuccapprox
  \let\nsuccapprox\textnsuccapprox
  \let\precnapprox\textprecnapprox
  \let\succnapprox\textsuccnapprox
  \let\subseteqq\textsubseteqq
  \let\nsubseteqq\textnsubseteqq
  \let\supseteqq\textsupseteqq
  \let\nsupseteqq\textnsupseteqq
  \let\dashV\textdashV
  \let\ndashV\textndashV
  \let\Dashv\textDashv
  \let\nDashv\textnDashv
  \let\DashV\textDashV
  \let\nDashV\textnDashV
  \let\downmodels\textdownmodels
  \let\ndownmodels\textndownmodels
  \let\upmodels\textupmodels
  \let\nupmodels\textnupmodels
  \let\upspoon\textupspoon
  \let\interleave\textinterleave
  \let\sslash\textsslash
  \let\pentagon\textpentagon
  \let\varhexagon\textvarhexagon
  \let\jinferior\textjinferior
  \let\slashdiv\textslashdiv
  \let\fivedots\textfivedots
  \let\oo\textoo
  \let\GaPa\textGaPa
  \let\HaPa\textHaPa
  \let\ViPa\textViPa
  \let\AcPa\textAcPa
  \let\SePa\textSePa
  \let\ZwPa\textZwPa
  \let\fullnote\textfullnote
  \let\halfnote\texthalfnote
  \let\Vier\textVier
  \let\Acht\textAcht
  \let\Sech\textSech
  \let\Zwdr\textZwdr
  \let\Mundus\textMundus
  \let\Moon\textMoon
  \let\ManFace\textManFace
  \let\WomanFace\textWomanFace
  \let\Fax\textFax
  \let\Fire\textFire
  \let\Bicycle\textBicycle
  \let\Gentsroom\textGentsroom
  \let\Ladiesroom\textLadiesroom
  \let\ccnc\textccnc
  \let\ccsa\textccsa
  \let\Info\textInfo
  \let\CESign\textCESign
  \let\neg\textneg
  \let\times\texttimes
  \let\div\textdiv
  \let\pm\textpm
  \let\cdot\textcdot
}% \psdmapshortnames
\newcommand*{\psdaliasnames}{%
  \let\epsdice\HyPsd@DieFace
  \let\fcdice\HyPsd@DieFace
  \let\MoonPha\HyPsd@MoonPha
  \let\mathdollar\textdollar
  \let\EyesDollar\textdollar
  \let\binampersand\textampersand
  \let\with\textampersand
  \let\mathunderscore\textunderscore
  \let\textvertline\textbar
  \let\mathsterling\textsterling
  \let\pounds\textsterling
  \let\brokenvert\textbrokenbar
  \let\mathsection\textsection
  \let\S\textsection
  \let\mathparagraph\textparagraph
  \let\MultiplicationDot\textperiodcentered
  \let\Squaredot\textperiodcentered
  \let\vartimes\textmultiply
  \let\MVMultiplication\textmultiply
  \let\eth\dh
  \let\crossd\textcrd
  \let\textbard\textcrd
  \let\bard\textcrd
  \let\textcrh\texthbar
  \let\crossh\texthbar
  \let\planck\texthbar
  \let\eng\ng
  \let\engma\ng
  \let\crossb\textcrb
  \let\textbarb\textcrb
  \let\barb\textcrb
  \let\Florin\textflorin
  \let\hv\texthvlig
  \let\hausak\texthtk
  \let\crossnilambda\textcrlambda
  \let\barlambda\textcrlambda
  \let\lambdabar\textcrlambda
  \let\lambdaslash\textcrlambda
  \let\textnrleg\textPUnrleg
  \let\textpipevar\textpipe
  \let\textdoublepipevar\textdoublepipe
  \let\textdoublebarpipevar\textdoublebarpipe
  \let\textcrg\textgslash
  \let\textdblig\textPUdblig
  \let\textqplig\textPUqplig
  \let\textcentoldstyle\textslashc
  \let\textbarc\textslashc
  \let\inva\textturna
  \let\vara\textscripta
  \let\invscripta\textturnscripta
  \let\rotvara\textturnscripta
  \let\hookb\texthtb
  \let\hausab\texthtb
  \let\varopeno\textopeno
  \let\curlyc\textctc
  \let\taild\textrtaild
  \let\hookd\texthtd
  \let\hausad\texthtd
  \let\er\textrhookschwa
  \let\epsi\textniepsilon
  \let\hookrevepsilon\textrhookrevepsilon
  \let\closedrevepsilon\textcloserevepsilon
  \let\barj\textbardotlessj
  \let\hookg\texthtg
  \let\varg\textscriptg
  \let\vod\textipagamma
  \let\invh\textturnh
  \let\udesc\textturnh
  \let\hookh\texthth
  \let\voicedh\texthth
  \let\hookheng\texththeng
  \let\ibar\textbari
  \let\vari\textniiota
  \let\tildel\textltilde
  \let\latfric\textbeltl
  \let\taill\textrtaill
  \let\lz\textlyoghlig
  \let\invm\textturnm
  \let\rotm\textturnm
  \let\legm\textturnmrleg
  \let\labdentalnas\textltailm
  \let\emgma\textltailm
  \let\nj\textltailn
  \let\enya\textltailn
  \let\tailn\textrtailn
  \let\closedniomega\textcloseomega
  \let\varomega\textcloseomega
  \let\invr\textturnr
  \let\rotr\textturnr
  \let\invlegr\textturnlonglegr
  \let\tailinvr\textturnrrtail
  \let\legr\textlonglegr
  \let\tailr\textrtailr
  \let\flapr\textfishhookr
  \let\flap\textfishhookr
  \let\tails\textrtails
  \let\curlyesh\textctesh
  \let\clickt\textturnt
  \let\tailt\textrtailt
  \let\ubar\textbaru
  \let\rotOmega\textniupsilon
  \let\invv\textturnv
  \let\pwedge\textturnv
  \let\invw\textturnw
  \let\rotw\textturnw
  \let\invy\textturny
  \let\roty\textturny
  \let\tailz\textrtailz
  \let\curlyz\textctz
  \let\curlyyogh\textctyogh
  \let\ejective\textglotstop
  \let\glottal\textglotstop
  \let\reveject\textrevglotstop
  \let\clickc\textstretchc
  \let\textstretchcvar\textstretchc
  \let\clickb\textbullseye
  \let\textObullseye\textbullseye
  \let\textctjvar\textctj
  \let\textturnsck\textturnk
  \let\dz\textdzlig
  \let\tesh\textteshlig
  \let\digamma\textdigammagreek
  \let\hardsign\cyrhrdsn
  \let\softsign\cyrsftsn
  \let\hebsin\hebshin
  \let\textsck\textPUsck
  \let\textscm\textPUscm
  \let\textscp\textPUscp
  \let\textrevscr\textPUrevscr
  \let\textrhooka\textPUrhooka
  \let\textrhooke\textPUrhooke
  \let\textrhookepsilon\textPUrhookepsilon
  \let\textrhookopeno\textPUrhookopeno
  \let\textdoublevertline\textbardbl
  \let\dag\textdagger
  \let\ddagger\textdaggerdbl
  \let\ddag\textdaggerdbl
  \let\mathellipsis\textellipsis
  \let\EurDig\texteuro
  \let\EURdig\texteuro
  \let\EurHv\texteuro
  \let\EURhv\texteuro
  \let\EurCr\texteuro
  \let\EURcr\texteuro
  \let\EurTm\texteuro
  \let\EURtm\texteuro
  \let\Eur\texteuro
  \let\Denarius\textDeleatur
  \let\agemO\textmho
  \let\EstimatedSign\textestimated
  \let\Ecommerce\textestimated
  \let\bindnasrepma\textinvamp
  \let\parr\textinvamp
  \let\MVRightArrow\textrightarrow
  \let\MVRightarrow\textrightarrow
  \let\MVArrowDown\textdownarrow
  \let\Force\textdownarrow
  \let\textglobrise\textnearrow
  \let\textglobfall\textsearrow
  \let\Lightning\textlightning
  \let\Conclusion\textRightarrow
  \let\dashedleftarrow\textdashleftarrow
  \let\dashedrightarrow\textdashrightarrow
  \let\varnothing\textemptyset
  \let\owns\textni
  \let\notni\textnotowner
  \let\varprop\textpropto
  \let\varangle\textsphericalangle
  \let\Anglesign\textsphericalangle
  \let\AngleSign\textsphericalangle
  \let\notdivides\textnmid
  \let\varowedge\textowedge
  \let\varovee\textovee
  \let\varint\textint
  \let\varoint\textoint
  \let\downtherefore\textbecause
  \let\textdotdiv\textdotminus
  \let\AC\textsim
  \let\wreath\textwr
  \let\nthickapprox\textnapprox
  \let\VHF\texttriplesim
  \let\notasymp\textnasymp
  \let\Doteq\textdoteqdot
  \let\corresponds\texthateq
  \let\Corresponds\texthateq
  \let\nequal\textneq
  \let\Congruent\textequiv
  \let\NotCongruent\textnequiv
  \let\notequiv\textnequiv
  \let\LessOrEqual\textleq
  \let\LargerOrEqual\textgeq
  \let\apprle\textlesssim
  \let\apprge\textgtrsim
  \let\varoplus\textoplus
  \let\varominus\textominus
  \let\varotimes\textotimes
  \let\varoslash\textoslash
  \let\varodot\textodot
  \let\ocirc\textcircledcirc
  \let\varocircle\textcircledcirc
  \let\varoast\textcircledast
  \let\oasterisk\textcircledast
  \let\rightvdash\textvdash
  \let\leftvdash\textdashv
  \let\nleftvdash\textndashv
  \let\downvdash\texttop
  \let\upvdash\textbot
  \let\nperp\textnupvdash
  \let\models\textvDash
  \let\rightmodels\textvDash
  \let\rightVdash\textVdash
  \let\rightModels\textVDash
  \let\nrightvdash\textnvdash
  \let\nrightmodels\textnvDash
  \let\nmodels\textnvDash
  \let\nrightVdash\textnVdash
  \let\nrightModels\textnVDash
  \let\lessclosed\textlhd
  \let\gtrclosed\textrhd
  \let\leqclosed\textunlhd
  \let\trianglelefteq\textunlhd
  \let\geqclosed\textunrhd
  \let\trianglerighteq\textunrhd
  \let\Bowtie\textbowtie
  \let\varcurlyvee\textcurlyvee
  \let\varcurlywedge\textcurlywedge
  \let\doublecap\textCap
  \let\doublecup\textCup
  \let\varsqsubsetneq\textsqsubsetneq
  \let\varsqsupsetneq\textsqsupsetneq
  \let\nlessclosed\textntriangleleft
  \let\ngtrclosed\textntriangleright
  \let\Clocklogo\textclock
  \let\ClockLogo\textclock
  \let\baro\textstmaryrdbaro
  \let\varparallelinv\textbbslash
  \let\CleaningA\textCircledA
  \let\Kutline\textCuttingLine
  \let\CutLine\textCuttingLine
  \let\Cutline\textCuttingLine
  \let\MoveUp\textUParrow
  \let\APLup\textbigtriangleup
  \let\Bleech\textbigtriangleup
  \let\MoveDown\textDOWNarrow
  \let\APLdown\textbigtriangledown
  \let\Diamond\textdiamond
  \let\varbigcirc\textbigcircle
  \let\Telefon\textPhone
  \let\Box\textboxempty
  \let\CheckedBox\textCheckedbox
  \let\XBox\textCrossedbox
  \let\CrossedBox\textCrossedbox
  \let\rightpointleft\textHandLeft
  \let\leftpointright\textHandRight
  \let\PointingHand\textHandRight
  \let\Pointinghand\textHandRight
  \let\Radiation\textRadioactivity
  \let\Yinyang\textYinYang
  \let\YingYang\textYinYang
  \let\Yingyang\textYinYang
  \let\Frowny\textfrownie
  \let\Smiley\textsmiley
  \let\Sun\textsun
  \let\Mercury\textmercury
  \let\textfemale\textPUfemale
  \let\female\textPUfemale
  \let\venus\textPUfemale
  \let\Venus\textPUfemale
  \let\Female\textPUfemale
  \let\Earth\textearth
  \let\mars\textmale
  \let\Mars\textmale
  \let\Male\textmale
  \let\Jupiter\textjupiter
  \let\Saturn\textsaturn
  \let\Uranus\texturanus
  \let\Neptune\textneptune
  \let\Pluto\textpluto
  \let\Aries\textaries
  \let\Taurus\texttaurus
  \let\Gemini\textgemini
  \let\Cancer\textcancer
  \let\Leo\textleo
  \let\Virgo\textvirgo
  \let\Libra\textlibra
  \let\Scorpio\textscorpio
  \let\Sagittarius\textsagittarius
  \let\Capricorn\textcapricornus
  \let\Aquarius\textaquarius
  \let\Pisces\textpisces
  \let\spadesuit\textspadesuitblack
  \let\Heart\textheartsuitwhite
  \let\heartsuit\textheartsuitwhite
  \let\diamondsuit\textdiamondsuitwhite
  \let\clubsuit\textclubsuitblack
  \let\eighthnote\textmusicalnote
  \let\Recycling\textrecycle
  \let\VarFlag\textFlag
  \let\textxswup\textdsmilitary
  \let\textuncrfemale\textPUuncrfemale
  \let\Football\textSoccerBall
  \let\CutLeft\textScissorRightBrokenBottom
  \let\Cutright\textScissorRightBrokenBottom
  \let\RightScissors\textScissorRight
  \let\Leftscissors\textScissorRight
  \let\Letter\textEnvelope
  \let\Writinghand\textWritingHand
  \let\checkmark\textCheckmark
  \let\davidstar\textDavidStar
  \let\llbracket\textlbrackdbl
  \let\rrbracket\textrbrackdbl
  \let\RightTorque\textlcurvearrowdown
  \let\Righttorque\textlcurvearrowdown
  \let\LeftTorque\textrcurvearrowdown
  \let\Lefttorque\textrcurvearrowdown
  \let\textvarobar\textobar
  \let\circledbslash\textobslash
  \let\obackslash\textobslash
  \let\varobslash\textobslash
  \let\odplus\textobot
  \let\varolessthan\textolessthan
  \let\varogreaterthan\textogreaterthan
  \let\divdot\textminusdot
  \let\doublesqcap\textsqdoublecap
  \let\doublesqcup\textsqdoublecup
  \let\merge\textdoublevee
  \let\leftVdash\textdashV
  \let\nleftVdash\textndashV
  \let\leftmodels\textDashv
  \let\nleftmodels\textnDashv
  \let\leftModels\textDashV
  \let\nleftModels\textnDashV
  \let\varparallel\textsslash
  \let\textheng\textPUheng
  \let\textlhookfour\textPUlhookfour
  \let\textscf\textPUscf
  \let\textaolig\textPUaolig
  \let\Ganz\textfullnote
  \let\Halb\texthalfnote
  \let\Womanface\textWomanFace
  \let\Faxmachine\textFax
  \let\CEsign\textCESign
}% \psdaliasnames
\endinput
%%
%% End of file `psdextra.def'.
