%%
%% This is file `se-iso-8859-3.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% stringenc.dtx  (with options: `general,iso-8859-3')
%% 
%% This is a generated file.
%% 
%% Project: stringenc
%% Version: 2019/11/29 v1.12
%% 
%% Copyright (C)
%%    2007-2011 Heiko Oberdiek
%%    2016-2019 Oberdiek Package Support Group
%% 
%% This work may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either
%% version 1.3c of this license or (at your option) any later
%% version. This version of this license is in
%%    https://www.latex-project.org/lppl/lppl-1-3c.txt
%% and the latest version of this license is in
%%    https://www.latex-project.org/lppl.txt
%% and version 1.3 or later is part of all distributions of
%% LaTeX version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainers of this work are
%% Heiko Oberdiek and the Oberdiek Package Support Group
%% https://github.com/ho-tex/stringenc/issues
%% 
%% 
%% The Base Interpreter refers to any `TeX-Format',
%% because some files are installed in TDS:tex/generic//.
%% 
%% This work consists of the main source file stringenc.dtx
%% and the derived files
%%    stringenc.sty, stringenc.pdf, stringenc.ins, stringenc.drv,
%%    se-utf32be.def, se-utf32le.def, se-utf8.def, se-utf16le.def,
%%    se-pdfdoc.def, se-iso-8859-1.def, se-cp1252.def,
%%    se-ascii.def, se-ascii-print.def, se-clean7bit.def,
%%    se-iso-8859-2.def, se-iso-8859-3.def, se-iso-8859-4.def,
%%    se-iso-8859-5.def, se-iso-8859-6.def, se-iso-8859-7.def,
%%    se-iso-8859-8.def, se-iso-8859-9.def, se-iso-8859-10.def,
%%    se-iso-8859-11.def, se-iso-8859-13.def, se-iso-8859-14.def,
%%    se-iso-8859-15.def, se-iso-8859-16.def, se-koi8-r.def,
%%    se-nextstep.def, se-mac-centeuro.def, se-mac-cyrillic.def,
%%    se-mac-roman.def, se-dec-mcs.def, se-cp437.def,
%%    se-cp850.def, se-cp852.def, se-cp855.def, se-cp858.def,
%%    se-cp865.def, se-cp866.def, se-cp1250.def, se-cp1251.def,
%%    se-cp1257.def, stringenc-test1.tex, stringenc-test2.tex.
%% 
\ProvidesFile{se-iso-8859-3.def}[2019/11/29 v1.12 stringenc: ISO-8859-3]
\def\SE@this{iso-8859-3}
\global\expandafter\let\csname\SE@PrefixTo\SE@this\endcsname
                       \SE@to@general
\global\expandafter\let\csname\SE@PrefixSurrogateTo\SE@this\endcsname
                       \SE@to@general@surrogate
\global\expandafter\let\csname\SE@PrefixFrom\SE@this\endcsname
                       \SE@from@general
\SE@MapDeclare{iso-8859-3}{A0}{00A0}% NO-BREAK SPACE
\SE@MapDeclare{iso-8859-3}{A1}{0126}% LATIN CAPITAL LETTER H WITH STROKE
\SE@MapDeclare{iso-8859-3}{A2}{02D8}% BREVE
\SE@MapDeclare{iso-8859-3}{A3}{00A3}% POUND SIGN
\SE@MapDeclare{iso-8859-3}{A4}{00A4}% CURRENCY SIGN
\SE@MapDeclare{iso-8859-3}{A6}{0124}% LATIN CAPITAL LETTER H WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{A7}{00A7}% SECTION SIGN
\SE@MapDeclare{iso-8859-3}{A8}{00A8}% DIAERESIS
\SE@MapDeclare{iso-8859-3}{A9}{0130}% LATIN CAPITAL LETTER I WITH DOT ABOVE
\SE@MapDeclare{iso-8859-3}{AA}{015E}% LATIN CAPITAL LETTER S WITH CEDILLA
\SE@MapDeclare{iso-8859-3}{AB}{011E}% LATIN CAPITAL LETTER G WITH BREVE
\SE@MapDeclare{iso-8859-3}{AC}{0134}% LATIN CAPITAL LETTER J WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{AD}{00AD}% SOFT HYPHEN
\SE@MapDeclare{iso-8859-3}{AF}{017B}% LATIN CAPITAL LETTER Z WITH DOT ABOVE
\SE@MapDeclare{iso-8859-3}{B0}{00B0}% DEGREE SIGN
\SE@MapDeclare{iso-8859-3}{B1}{0127}% LATIN SMALL LETTER H WITH STROKE
\SE@MapDeclare{iso-8859-3}{B2}{00B2}% SUPERSCRIPT TWO
\SE@MapDeclare{iso-8859-3}{B3}{00B3}% SUPERSCRIPT THREE
\SE@MapDeclare{iso-8859-3}{B4}{00B4}% ACUTE ACCENT
\SE@MapDeclare{iso-8859-3}{B5}{00B5}% MICRO SIGN
\SE@MapDeclare{iso-8859-3}{B6}{0125}% LATIN SMALL LETTER H WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{B7}{00B7}% MIDDLE DOT
\SE@MapDeclare{iso-8859-3}{B8}{00B8}% CEDILLA
\SE@MapDeclare{iso-8859-3}{B9}{0131}% LATIN SMALL LETTER DOTLESS I
\SE@MapDeclare{iso-8859-3}{BA}{015F}% LATIN SMALL LETTER S WITH CEDILLA
\SE@MapDeclare{iso-8859-3}{BB}{011F}% LATIN SMALL LETTER G WITH BREVE
\SE@MapDeclare{iso-8859-3}{BC}{0135}% LATIN SMALL LETTER J WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{BD}{00BD}% VULGAR FRACTION ONE HALF
\SE@MapDeclare{iso-8859-3}{BF}{017C}% LATIN SMALL LETTER Z WITH DOT ABOVE
\SE@MapDeclare{iso-8859-3}{C0}{00C0}% LATIN CAPITAL LETTER A WITH GRAVE
\SE@MapDeclare{iso-8859-3}{C1}{00C1}% LATIN CAPITAL LETTER A WITH ACUTE
\SE@MapDeclare{iso-8859-3}{C2}{00C2}% LATIN CAPITAL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{C4}{00C4}% LATIN CAPITAL LETTER A WITH DIAERESIS
\SE@MapDeclare{iso-8859-3}{C5}{010A}% LATIN CAPITAL LETTER C WITH DOT ABOVE
\SE@MapDeclare{iso-8859-3}{C6}{0108}% LATIN CAPITAL LETTER C WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{C7}{00C7}% LATIN CAPITAL LETTER C WITH CEDILLA
\SE@MapDeclare{iso-8859-3}{C8}{00C8}% LATIN CAPITAL LETTER E WITH GRAVE
\SE@MapDeclare{iso-8859-3}{C9}{00C9}% LATIN CAPITAL LETTER E WITH ACUTE
\SE@MapDeclare{iso-8859-3}{CA}{00CA}% LATIN CAPITAL LETTER E WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{CB}{00CB}% LATIN CAPITAL LETTER E WITH DIAERESIS
\SE@MapDeclare{iso-8859-3}{CC}{00CC}% LATIN CAPITAL LETTER I WITH GRAVE
\SE@MapDeclare{iso-8859-3}{CD}{00CD}% LATIN CAPITAL LETTER I WITH ACUTE
\SE@MapDeclare{iso-8859-3}{CE}{00CE}% LATIN CAPITAL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{CF}{00CF}% LATIN CAPITAL LETTER I WITH DIAERESIS
\SE@MapDeclare{iso-8859-3}{D1}{00D1}% LATIN CAPITAL LETTER N WITH TILDE
\SE@MapDeclare{iso-8859-3}{D2}{00D2}% LATIN CAPITAL LETTER O WITH GRAVE
\SE@MapDeclare{iso-8859-3}{D3}{00D3}% LATIN CAPITAL LETTER O WITH ACUTE
\SE@MapDeclare{iso-8859-3}{D4}{00D4}% LATIN CAPITAL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{D5}{0120}% LATIN CAPITAL LETTER G WITH DOT ABOVE
\SE@MapDeclare{iso-8859-3}{D6}{00D6}% LATIN CAPITAL LETTER O WITH DIAERESIS
\SE@MapDeclare{iso-8859-3}{D7}{00D7}% MULTIPLICATION SIGN
\SE@MapDeclare{iso-8859-3}{D8}{011C}% LATIN CAPITAL LETTER G WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{D9}{00D9}% LATIN CAPITAL LETTER U WITH GRAVE
\SE@MapDeclare{iso-8859-3}{DA}{00DA}% LATIN CAPITAL LETTER U WITH ACUTE
\SE@MapDeclare{iso-8859-3}{DB}{00DB}% LATIN CAPITAL LETTER U WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{DC}{00DC}% LATIN CAPITAL LETTER U WITH DIAERESIS
\SE@MapDeclare{iso-8859-3}{DD}{016C}% LATIN CAPITAL LETTER U WITH BREVE
\SE@MapDeclare{iso-8859-3}{DE}{015C}% LATIN CAPITAL LETTER S WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{DF}{00DF}% LATIN SMALL LETTER SHARP S
\SE@MapDeclare{iso-8859-3}{E0}{00E0}% LATIN SMALL LETTER A WITH GRAVE
\SE@MapDeclare{iso-8859-3}{E1}{00E1}% LATIN SMALL LETTER A WITH ACUTE
\SE@MapDeclare{iso-8859-3}{E2}{00E2}% LATIN SMALL LETTER A WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{E4}{00E4}% LATIN SMALL LETTER A WITH DIAERESIS
\SE@MapDeclare{iso-8859-3}{E5}{010B}% LATIN SMALL LETTER C WITH DOT ABOVE
\SE@MapDeclare{iso-8859-3}{E6}{0109}% LATIN SMALL LETTER C WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{E7}{00E7}% LATIN SMALL LETTER C WITH CEDILLA
\SE@MapDeclare{iso-8859-3}{E8}{00E8}% LATIN SMALL LETTER E WITH GRAVE
\SE@MapDeclare{iso-8859-3}{E9}{00E9}% LATIN SMALL LETTER E WITH ACUTE
\SE@MapDeclare{iso-8859-3}{EA}{00EA}% LATIN SMALL LETTER E WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{EB}{00EB}% LATIN SMALL LETTER E WITH DIAERESIS
\SE@MapDeclare{iso-8859-3}{EC}{00EC}% LATIN SMALL LETTER I WITH GRAVE
\SE@MapDeclare{iso-8859-3}{ED}{00ED}% LATIN SMALL LETTER I WITH ACUTE
\SE@MapDeclare{iso-8859-3}{EE}{00EE}% LATIN SMALL LETTER I WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{EF}{00EF}% LATIN SMALL LETTER I WITH DIAERESIS
\SE@MapDeclare{iso-8859-3}{F1}{00F1}% LATIN SMALL LETTER N WITH TILDE
\SE@MapDeclare{iso-8859-3}{F2}{00F2}% LATIN SMALL LETTER O WITH GRAVE
\SE@MapDeclare{iso-8859-3}{F3}{00F3}% LATIN SMALL LETTER O WITH ACUTE
\SE@MapDeclare{iso-8859-3}{F4}{00F4}% LATIN SMALL LETTER O WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{F5}{0121}% LATIN SMALL LETTER G WITH DOT ABOVE
\SE@MapDeclare{iso-8859-3}{F6}{00F6}% LATIN SMALL LETTER O WITH DIAERESIS
\SE@MapDeclare{iso-8859-3}{F7}{00F7}% DIVISION SIGN
\SE@MapDeclare{iso-8859-3}{F8}{011D}% LATIN SMALL LETTER G WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{F9}{00F9}% LATIN SMALL LETTER U WITH GRAVE
\SE@MapDeclare{iso-8859-3}{FA}{00FA}% LATIN SMALL LETTER U WITH ACUTE
\SE@MapDeclare{iso-8859-3}{FB}{00FB}% LATIN SMALL LETTER U WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{FC}{00FC}% LATIN SMALL LETTER U WITH DIAERESIS
\SE@MapDeclare{iso-8859-3}{FD}{016D}% LATIN SMALL LETTER U WITH BREVE
\SE@MapDeclare{iso-8859-3}{FE}{015D}% LATIN SMALL LETTER S WITH CIRCUMFLEX
\SE@MapDeclare{iso-8859-3}{FF}{02D9}% DOT ABOVE
\endinput
%%
%% End of file `se-iso-8859-3.def'.
